      SUBROUTINE bury(n_control,zsed,delz,pore,kmax,
     *          calgg,orggg,sed_ml_mass,
     *          rain_cal_p,ttrcal,c_advect,
     *          rain_clay_p,
     *          nyear,
     *          buried_mass,buried_calfrac,depth_age,
     *          i_parallel,
     *          ip_sedmain_max,nz_sedmain_max,i_bur_rec_max)

c     n_control = 0  ==> initialize
c     n_control = 1  ==> accumulate average
c     n_control = 2  ==> do burial

      PARAMETER(ip_bury_max = 2600)

c     arguments
      REAL zsed(nz_sedmain_max),delz(nz_sedmain_max)
      REAL pore(nz_sedmain_max,ip_sedmain_max)
      REAL calgg(nz_sedmain_max,ip_sedmain_max)
      REAL orggg(nz_sedmain_max,ip_sedmain_max)
      REAL sed_ml_mass(ip_sedmain_max)
      REAL rain_cal_p(ip_sedmain_max)
      REAL ttrcal(ip_sedmain_max)
      REAL c_advect(ip_sedmain_max)
      REAL rain_clay_p(ip_sedmain_max)

c     results
      REAL buried_mass(i_bur_rec_max,ip_sedmain_max)
      REAL buried_calfrac(i_bur_rec_max,ip_sedmain_max)
      REAL depth_age(i_bur_rec_max)

c     internal variables (saved)
      REAL rain_cal_sum(ip_bury_max), ttrcal_sum(ip_bury_max)
      REAL rain_clay_sum(ip_bury_max)

c     internal variables (temporary)
      REAL buried_mass_step(ip_bury_max)
      REAL calml(ip_bury_max), calml_new(ip_bury_max)
      REAL calbur(ip_bury_max), calbur_new(ip_bury_max)
      REAL caltot(ip_bury_max), caltot_new(ip_bury_max)
      REAL calgg_est(ip_bury_max)
      REAL sed_ml_mass_new(ip_bury_max)

      SAVE rain_cal_sum, rain_clay_sum, ttrcal_sum

      IF( n_control .EQ. 0 ) THEN
c     ==> initialize

         DO 1 ip = 1, i_parallel
            rain_cal_sum(ip) = 0.
            rain_clay_sum(ip) = 0.
            ttrcal_sum(ip) = 0.
            n_accum = 0
            buried_mass(1,ip) = 500.
            buried_calfrac(1,ip) = calgg(kmax,ip)
            DO 1 k = 2, i_bur_rec_max
               buried_mass(k,ip) = 0.
               buried_calfrac(k,ip) = calgg(kmax,ip)
 1       CONTINUE

         CALL set_pore(calgg,zsed,pore,
     *              kmax,i_parallel,ip_sedmain_max,nz_sedmain_max)

         CALL get_sed_ml_mass(delz,pore,
     *     sed_ml_mass,
     *     nz_sedmain_max,i_parallel,ip_sedmain_max,kmax)


      ELSEIF( n_control .EQ. 1) THEN
c     ==> accumulate fluxes

         DO 2 ip = 1, i_parallel
            rain_cal_sum(ip) = rain_cal_sum(ip)
     $           + rain_cal_p(ip)
            rain_clay_sum(ip) = rain_clay_sum(ip)
     $           + rain_clay_p(ip)
            ttrcal_sum(ip) = ttrcal_sum(ip)
     $           + ttrcal(ip)
 2       CONTINUE
         n_accum = n_accum + 1

      ELSE
c     else n_control = 2  ==> do burial

c        add up total calcite for debugging

         DO 105 ip = 1, i_parallel
            calml(ip) = sed_ml_mass(ip)
     c                   * calgg(kmax,ip)
            calbur(ip) = 0.
            DO 105 k = 1, i_bur_rec_max
               calbur(ip) = calbur(ip)
     *                      + buried_mass(k,ip)
     c                      * buried_calfrac(k,ip)
 105     CONTINUE

         DO 102 ip = 1, i_parallel

            caltot(ip) = calml(ip) + calbur(ip)
            rain_cal_sum(ip) = rain_cal_sum(ip)
     $           + rain_cal_p(ip) * 1.
            rain_clay_sum(ip) = rain_clay_sum(ip)
     $           + rain_clay_p(ip) * 1.
            ttrcal_sum(ip) = ttrcal_sum(ip)
     $           + ttrcal(ip) * 1.

  102    CONTINUE

         n_accum = n_accum + 1


c        estimate the change in calgg, then calculate new porosities

         DO ip = 1, i_parallel
            
            calgg_est(ip) = (
     *                calgg(kmax,ip) * sed_ml_mass(ip)
     *              + rain_cal_sum(ip) * 100.
     *              - ttrcal_sum(ip) * 100.
     *           ) / sed_ml_mass(ip)

         ENDDO

         CALL set_est_pore(calgg_est,zsed,pore,
     *              kmax,i_parallel,ip_sedmain_max,nz_sedmain_max)

         CALL get_sed_ml_mass(delz,pore,
     *     sed_ml_mass_new,
     *     nz_sedmain_max,i_parallel,ip_sedmain_max,kmax)


         DO 10 k = i_bur_rec_max, 1, -1
            IF ( nyear .GE. depth_age(k) ) THEN
               n_depth = k + 1
            ENDIF
 10      CONTINUE

c     calculate mass buried this time step
c     units of g/cm2 per this time step


         DO 30 ip = 1, i_parallel
            buried_mass_step(ip) = rain_cal_sum(ip) * 100.
     *           - ttrcal_sum(ip) * 100.
     *           + rain_clay_sum(ip)

            buried_mass_step(ip) = buried_mass_step(ip)
     *           + sed_ml_mass(ip)
     *           - sed_ml_mass_new(ip)
 30      CONTINUE


c     now do some burial
c     this loop won't parallelize very well.  too bad.
         DO 40 ip = 1, i_parallel

            DO 50 k = 1, n_depth
               IF( buried_mass(k,ip) .GT. 0. ) THEN
                  n_coretop = k
               ENDIF
 50         CONTINUE
c        find the "latest" box with mass in it, 
c        one ip at a time

            IF( buried_mass_step(ip) .GT. 0. ) THEN
c         then we're accumulating -- that's easy

c          add buried calcite to the sediment record
               buried_calfrac(n_depth,ip) =
     *           (   buried_mass(n_depth,ip)
     *               * buried_calfrac(n_depth,ip)
     *             + buried_mass_step(ip)
     *               * calgg(kmax,ip)
     *           )
     *         / (   buried_mass(n_depth,ip)
     *             + buried_mass_step(ip)
     *           )

c          add buried mass to sediment record
               buried_mass(n_depth,ip) =
     *           buried_mass(n_depth,ip)
     *           + buried_mass_step(ip)

c          adjust calgg
               DO 90 k = 1, kmax
                  calgg(k,ip) = (
     *              calgg(k,ip) * sed_ml_mass(ip)
c                    [ g calcite (old) in ml ]
     *              + rain_cal_sum(ip) * 100.
     *              - ttrcal_sum(ip) * 100.
     *              - buried_mass_step(ip)
     *                * calgg(kmax,ip)
c                     [ minus calcite buried ]
     *                       )
     *               / sed_ml_mass_new(ip)
 90            CONTINUE

c            all business is complete at this point

            ELSE
c         or else there's chemical erosion -- bms < 0

               IF( - buried_mass_step(ip) .GT.
     *               buried_mass(n_coretop,ip)
     *           ) THEN

c            then we're using up the entire coretop box by erosion
c            assume that this can only happen once per year timestep.

c            calculate the fraction of calcite in the upwelling
c            material by combining the fractions of boxes n_coretop
c            (until it's used up) and n_coretop - 1 (below top)

c                  write(6,*) "into box depletion in bury"

                  up_cal_frac =
     *              (   buried_mass(n_coretop,ip)
     *                  * buried_calfrac(n_coretop,ip)
     *                + ( ( - buried_mass_step(ip)
     *                      - buried_mass(n_coretop,ip)
     *                    )
     *                    * buried_calfrac(n_coretop-1,ip)
     *                  )
     *              )
     *            / ( - buried_mass_step(ip) )

c               adjust the sediment record to reflect erosion

                  buried_mass(n_coretop-1,ip) =
     $                 buried_mass(n_coretop-1,ip) +
     $                 ( buried_mass_step(ip)
     $                   + buried_mass(n_coretop, ip)
     $                 )
                  buried_mass(n_coretop,ip) = 0.
                  n_coretop = n_coretop - 1

               ELSE
c            or else erosion can come entirely out of the box
c            n_coretop, and the upwelling calcite fraction is
c            simply  buried_calfrac(n_coretop,ip)

                  up_cal_frac = buried_calfrac(n_coretop,ip)

c               adjust the sediment record

                  buried_mass(n_coretop,ip)
     *              = buried_mass(n_coretop,ip)
     *                + buried_mass_step(ip)

               ENDIF

c            now gotta adjust calgg

               cal_total_new = sed_ml_mass(ip)
     *                        * calgg(kmax,ip)
     *                      + rain_cal_sum(ip) * 100.
     *                      - ttrcal_sum(ip) * 100.
     *                      - buried_mass_step(ip)
     *                        * up_cal_frac
              
               DO 60 k = 1, kmax
                  calgg(k,ip) = cal_total_new / sed_ml_mass_new(ip)
                  IF(calgg(k,ip) .LT. 0.) THEN
                     calgg(k,ip) = 1.E-6
                     write(6,*) "calgg reached 0 in ip", ip
                  ENDIF
 60            CONTINUE

            ENDIF
c           end of the "erosion IF"


c           add up new total calcite for debugging
            calml_new(ip) = sed_ml_mass_new(ip)
     c                   * calgg(kmax,ip)
            calbur_new(ip) = 0.
            DO 205 k = 1, i_bur_rec_max
               calbur_new(ip) = calbur_new(ip)
     c                          + buried_mass(k,ip)
     c                          * buried_calfrac(k,ip)
 205        CONTINUE
            caltot_new(ip) = calml_new(ip) + calbur_new(ip)

            IF( ABS(   caltot(ip)
     *                 + rain_cal_p(ip)*100. - ttrcal(ip)*100.
     c                 - caltot_new(ip)
     C             )
     c          .GE. 1.E-8
     c        ) THEN
               WRITE(6,*) "something fucked up in bury ", ip
            ENDIF


 40      CONTINUE
c        end of the ip loop


         DO 111 ip = 1, i_parallel
            rain_cal_sum(ip) = 0.
            rain_clay_sum(ip) = 0.
            ttrcal_sum(ip) = 0.
            n_accum = 0
            sed_ml_mass(ip) = sed_ml_mass_new(ip)
 111     CONTINUE

      ENDIF

      RETURN
      END

      SUBROUTINE set_pore(calgg,z,pore,
     *              kmax,i_parallel,ip_sedmain_max,nz_sedmain_max)

      REAL pore(nz_sedmain_max,ip_sedmain_max)

      REAL calgg(nz_sedmain_max,ip_sedmain_max)
      REAL z(nz_sedmain_max)

      DO ip = 1, i_parallel

c         pore_max = 0.65*calgg(kmax,ip) +0.85*(1-calgg(kmax,ip))
         pore_max = 1 - ( 0.483 + 0.45 * calgg(kmax,ip) ) / 2.5
         exp_pore = 0.25*calgg(kmax,ip) + 3. *(1-calgg(kmax,ip))

         DO k = 2, kmax
            pore(k,ip) = exp(-z(k)/exp_pore) * (1.-pore_max) + pore_max
         ENDDO
      ENDDO

      RETURN

      END


      SUBROUTINE set_est_pore(calgg,z,pore,
     *              kmax,i_parallel,ip_sedmain_max,nz_sedmain_max)

      REAL pore(nz_sedmain_max,ip_sedmain_max)

      REAL calgg(ip_sedmain_max)
      REAL z(nz_sedmain_max)

      DO ip = 1, i_parallel

c         pore_max = 0.65*calgg(ip) +0.85*(1-calgg(ip))
         pore_max = 1 - ( 0.483 + 0.45 * calgg(ip) ) / 2.5
         exp_pore = 0.25*calgg(ip) + 3. *(1-calgg(ip))

         DO k = 2, kmax
            pore(k,ip) = exp(-z(k)/exp_pore) * (1.-pore_max) + pore_max
         ENDDO
      ENDDO

      RETURN

      END


      SUBROUTINE get_sed_ml_mass(delz,pore,
     *     sed_ml_mass,
     *     nz_sedmain_max,i_parallel,ip_sedmain_max,kmax)

      REAL delz(nz_sedmain_max)
      REAL pore(nz_sedmain_max,ip_sedmain_max)
      REAL sed_ml_mass(ip_sedmain_max)

      DO 40 ip = 1, i_parallel
         sed_ml_mass(ip) = 0.
         DO 40 k = 1, kmax
            sed_ml_mass(ip) = sed_ml_mass(ip)
     *                    + delz(k)
     *                      * ( 1 - pore(k,ip) )
     *                      * 2.5
   40 CONTINUE

      RETURN
      END

