c#define Read_Parms
c#define Parm_Dry_Dep
c#define Parm_Hg_Sinking_Rate
c#define Parm_Hg_Binding_Constant
c#define Parm_Basin
c#define Hg_Deposition_Basin
c#define Remember_Hg_2P_Binding_Constant
c#define Remember_Hg_Anthro_EF

c#define Debug_Printout

#define Hg_Photo_Chem
#define Hg_Photo_Chem_Lat
#define Hg_Sinking
#define Hg_Sinking_Implicit
#define Hg_Subsurface_Speciation

c#define Hg_Anthro_Hangover

#define Hg_Deposition_Frac
#define Hg_Degas_0_MDF
#define Hg_Degas_DM_MDF
#define Hg_2P_0_MF
#define Hg_MM_0_MF
#define Hg_2P_MM_MDF
#define Hg_MM_2P_MDF
#define Hg_Particles_MDF

#define Hg_Deposition
#define Hg_Sinking_Rate 500.

#define Hg_2P_Atm_Dep_Rate 2.d-13  /* 2 mol/l yr surface layer global average */
#define Hg_0_Atm_Dep_Rate  1.d-13  /* 1 mol/l yr surface layer global average */
#define Hg_Natural_Scale   0.13
#define Hg_1850_Scale      0.28
      
#define Hg_Anthro_EF 4      /* Streets 2017 atm model */

#define Hg_Mass_Dep_202_199 4
#define Hg_Mass_Dep_202_200 2

#define Hg_2P_Binding_Constant 2.d6 /* from Zhang */
#define POC_Sinking_Rate 500.  /* meters per year */ 
c     from 3 mol C / m2 year export prod, and surface POC of 0.5 mol/m3

      subroutine hg_cycle(nyear)

c      implicit none

      INCLUDE 'parameter.include'
      INCLUDE 'equivalence.include'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.chemis'
      include 'common.divers'
      INCLUDE 'common.production'
      include 'common.wathic'
      include 'common.topogr'
      include 'common.biocon'
      include 'common.hg'

#define i0  1
#define iDM 2
#define iMM 3
#define i2P 4
#define i198 1
#define i202 2
#define i199 3
#define i200 4

      real rate_constants(4,4), 
     $     mdf_alpha(4,4),
     $     mif_199_alpha(4,4),
     $     epsilon_199(4,4), epsilon_202(4,4), epsilon_200(4,4),
     $     rate_199(4,4), rate_200(4,4),
     $     rate_202(4,4),
     $     degas_rate(4), degas_199_rate(4),
     $     degas_202_rate(4),
     $     fluxes(4,4), flux_alphas(4,4),
     $     hg_0_atm_dep_rate, hg_0_atm_dep_frac, par, npp,
     $     photo_demeth_rate_scale, photo_red_rate_scale

      real a(4,4),b(4)

      character*80 filename
      character*20 string_name

      data ifirst /1/
      real hg_sinking_rate, hg_anthro_ef, z_grid(11)
      DATA z_grid/-.25,-.75,-1.50,-2.50,-4.50,-7.00,-10.00,-20.00,
     *            -30.00,-40.00,-50.00/

      save

#ifdef Read_Parms
      if( ifirst .EQ. 1) then
#ifdef Parm_Hg_Sinking_Rate
         write(6,*) "waiting for hg_sinking_rate" 
         read(5,*) hg_sinking_rate
#else
         hg_sinking_rate = Hg_Sinking_Rate
#endif
#ifdef Parm_Dry_Dep
         write(6,*) "waiting for hg dry dep fraction" 
         read(5,*) hg_0_atm_dep_frac
         hg_0_atm_dep_rate = Hg_2P_Atm_Dep_Rate * hg_0_atm_dep_frac
#else
         hg_0_atm_dep_rate = Hg_0_Atm_Dep_Rate
#endif
#ifdef Parm_Hg_Binding_Constant
         write(6,*) "waiting for hg binding constant" 
         read(5,*) hg_2p_binding_constant
         write(6,*) hg_2p_binding_constant
#else
         hg_2p_binding_constant = Hg_2P_Binding_Constant
#endif
#ifdef Parm_Basin
         write(6,*) "waiting for the basin to hit"
         read(5,*) ibasin_deposition
#endif

         ifirst = 0
      endif

c#ifdef Hg_Anthro_EF
      hg_anthro_ef = Hg_Anthro_EF
c#else
c      hg_anthro_ef = 0.d0
c#endif

#else  /* readParms */
      hg_sinking_rate = Hg_Sinking_Rate
      hg_anthro_ef = Hg_Anthro_EF
      hg_2p_binding_constant = Hg_2P_Binding_Constant
      hg_0_atm_dep_rate = Hg_0_Atm_Dep_Rate 
#endif   /* readParms */

      poc_inv = 0.d0
      poc_profile = 0.d0
      poc_profile_n = 0
      hg_particle_lifetime = 0.d0
      hg_deposition = 0.d0
      hg_0_degassing = 0.d0
      hg_dm_degassing = 0.d0
c     surface poc inventory
      DO j=jl1,jle
         DO i=1,ie
            if(prorca(i,j) .GT. 0.d0) then
               poc_inv(i,j,1) = prorca(i,j)  ! mol/l timestep
     $              * 1.d3
     $              * ddz(i,j,1) / 1.d2     ! mol/m2 timestep   
     $              / POC_Sinking_Rate     ! m/yr sinking velocity -> mol/m3
     $              / 1.d3                 ! mol/l
               poc_profile(1) = poc_profile(1) + poc_inv(i,j,1)
               n_poc_profile(1) = n_poc_profile(1) + 1
            endif
         enddo
      enddo

c     poc inv subsurface
      DO j=jl1,jle
         DO i=1,ie
            do k=2,ke
               if(prorca(i,j) .GT. 0.d0) then
                  poc_inv(i,j,k) = poc_inv(i,j,1)
     $                * poc_flux_frac(k)
                  poc_profile(k) = poc_profile(k) + poc_inv(i,j,k)
                  n_poc_profile(k) = n_poc_profile(k) + 1
               endif
            enddo
         enddo
      enddo

#ifdef Hg_Deposition   /* distributes totals into species */

      DO j=jl1,jle
         DO i=1,ie
            if(prorca(i,j) .GT. 0.d0) then
               do k = 1, ke

                  rate_constants = 0.d0

                  if( k .EQ. 1 ) then  ! degassing
                     rate_constants( i0, i0 ) = 22.d0   ! 3 m/d/50m*365=22.
#ifdef Goose_Hg0_Gasex
     $                    * GooseFactor
#endif
                     rate_constants( iDM, iDM ) = 22.d0
#ifdef Goose_DMHg_Gasex
     $                    * GooseFactor
c                     write(6,*) "goosing DM degassing ", GooseFactor
#endif
                  endif

                  photo_demeth_rate_scale =
     $                 exp( z_grid(k)*1.d2 / 100.d0 ) ! 100 m efold
#ifdef Hg_Photo_Chem_Lat
     $                 * prlat(i,j)
#endif
#ifdef Goose_Photo_Demeth
                  photo_demeth_rate_scale = photo_demeth_rate_scale
     $                 * GooseFactor
#endif

                  photo_red_rate_scale = exp( z_grid(k)*1.d2 / 20.d0 ) ! 100 m efold
#ifdef Hg_Photo_Chem_Lat
     $                 * prlat(i,j)
#endif
#ifdef Goose_Photo_Red
                  photo_red_rate_scale = photo_red_rate_scale
     $                 * GooseFactor
#endif

                  par = 240.d0 * photo_demeth_rate_scale
                  npp = prorca(i,j) * ddz(i,j,1) / 1.d5 ! mol/m2 yr
     $                 * 12.d0 / 365.d0                 ! gC / m2 day

                  bio_rate_scale = poc_inv(i,j,k) ! mol/l
     $                 * 1.d6   ! MethylationRateScale ! want 3/yr at surface
#ifdef GooseBio
     $                 * GooseBio
#endif

#define New_Kinetics
#ifdef New_Kinetics
c     from semeniuk
                  rate_constants( i2P, iMM ) = bio_rate_scale   ! k1

#ifdef Goose_2pMm
     $                 * Goose_2pMm
#endif
#ifdef GooseSubsurface_2pMM
                  if( k .GT. 2) then
                     rate_constants( i2P, iMM ) = 
     $                    rate_constants( i2P, iMM )
     $                 * 2.d0
                  endif
#endif
                  hg_2p_meth_rate(i,j,k) = rate_constants( i2P, iMM )

                  rate_constants( i2P, iDM ) = bio_rate_scale
     $                                       * 0.01d0           ! k2
#ifdef Goose_2pDm
     $                * Goose_2pDm
#endif

                  rate_constants( iMM, iDM ) = bio_rate_scale
     $                                       * 0.1d0            ! k3
#ifdef Goose_MmDm
     $                * Goose_MmDm
#endif
                  rate_constants( iMM, i2P ) = bio_rate_scale 
     $                                       * 10.d0            ! k4
#ifdef Goose_Mm2p
     $                * Goose_Mm2p
#endif
                  bio_ox_demeth = rate_constants( iMM, i2P )

                  rate_constants( iDM, iMM ) = bio_rate_scale
     $                                       * 0.1d0            ! k5
#ifdef Goose_DmMm
     $                * Goose_DmMm
#endif

                  photo_demeth = 350.d0 * photo_demeth_rate_scale ! bergquist 20% 300 min
                  bio_red_demeth = 
     $                   bio_rate_scale / 3.d0 ! norm to 1
     $                   * 3.5d-9           ! k6
     $                   * 3.14d7 ! /yr

                  rate_constants( iMM, i0 ) = ( photo_demeth
#ifdef Goose_Mm0_Photo
     $                * Goose_Mm0_Photo
#endif
     $                 + bio_red_demeth )
#ifdef Goose_Mm0
     $                * Goose_Mm0
#endif

c     fits to figure 2 in soerensen 2010
                  rate_constants( i2P, i0 ) = (
     $                   82.d0 * photo_red_rate_scale
#ifdef Goose_2p0_Photo
     $                 * Goose_2p0_Photo
#endif
     $                 + 1.3d0/3.d0 * bio_rate_scale
#ifdef Goose_2p0_Bio
     $                 * Goose_2p0_Bio
#endif
     $                 )
#ifdef Goose_2p0
     $                * Goose_2p0
#endif
                  rate_constants( i0, i2P ) = (
     $                   776.d0 * photo_red_rate_scale
     $                 + 3.15/3.d0 * bio_rate_scale )
#ifdef Goose_02p
     $                * Goose_02p
#endif

#endif

#ifdef Hg_Sinking_Implicit
                  if( k .EQ. 1 ) then
                     rate_constants( i2P, i2P ) = 1.d0 ! rate dependence on hg_2p
     $                    * ( 1.d0 -
     $                      1 /
     $                        ( hg_2p_binding_constant
     $                        * poc_inv(i,j,k)  ! mol/l
     $                          * 12.d0 / 1000.d0  ! kg / l (really)
     $                        + 1.
     $                        )
     $                      )     ! hg_2p_bound, mol/L
     $                    * 1.d3 ! mol/m3
     $                    * hg_sinking_rate ! hg_2p_sinking_flux, mol/m2 yr
     $                    / ( ddz(i,j,k)/1.d2 )
     $                    / 1.d3 ! time tendency on hg_2p, mol/l yr
                  endif
#endif

                  mdf_alpha = 0.d0
                  mif_199_alpha = 0.d0

#ifdef Hg_2P_MM_MDF
                  mdf_alpha( i2P, iMM) = -2.5d0  ! Rodriguiz-Gonzolez 2009
#endif

#ifdef Hg_MM_2P_MDF
                  mdf_alpha( iMM, i2P) = -0.4d0 ! Kritee 2009 biotic 
#endif

#ifdef Hg_Particles_MDF
                  mdf_alpha( i2P, i2P ) = -0.6d0 ! particles Weiderhold
#endif

                  if( k .EQ. 1) then
#ifdef Hg_Degas_0_MDF
                     mdf_alpha( i0, i0 ) = -0.4d0 ! degassing Zheng 2007
#endif

#ifdef Hg_Degas_DM_MDF
                     mdf_alpha( iDM, iDM ) = -0.4d0 ! degassing
#endif
                  endif

#ifdef Hg_2P_0_MF
                  mif_199_alpha( i2P, i0 ) = -1.75d0 ! Sun ms
                  mdf_alpha( i2P, i0 ) =
     $                 (
     $                   ( 82.d0 * photo_red_rate_scale )
     $                 * ( -1.75d0 / 1.2d0 ) ! Blum 2014 ratio
     $                 + ( 1.3d0/3.d0 * bio_rate_scale )
     $                 * ( -1.7d0 )   ! Kritee 2008 biotic
     $                 )
     $                 / ( 82.d0 * photo_red_rate_scale
     $                   + 1.3d0/3.d0 * bio_rate_scale
     $                   )  ! weighted average
#endif

#ifdef Hg_MM_0_MF
#ifdef Hg_MM_Photo_2P
                  mif_199_alpha( iMM, i2P ) =
     $                 -2.5 * photo_demeth ! wildly variable 
     $                 / ( photo_demeth + bio_ox_demeth ) ! assumes bio = 0                  
                  mdf_alpha( iMM, i2P ) = 
     $                 (
     $                   photo_demeth
     $                 * ( -2.5d0 / 2.4d0 ) ! Blum 2014 ratio
     $                 + bio_ox_demeth
     $                 * ( -0.4d0 )   ! Kritee 2008 biotic
     $                 )
     $                 / ( photo_demeth + bio_ox_demeth )
#else
                  mif_199_alpha( iMM, i0 ) = -2.5 ! wildly variable 
#ifdef Goose_Mm0_MIF
     $                 * Goose_Mm0_MIF
#endif
                  mdf_alpha( iMM, i0 ) =
     $                 (
     $                   photo_demeth
     $                 * ( -2.5d0
#ifdef Goose_Mm0_MIF
     $                   * Goose_Mm0_MIF
#endif
     $                   / 2.4d0 ) ! Blum 2014 ratio
     $                 + bio_red_demeth
     $                 * ( -1.7d0 )   ! Kritee 2008 biotic
     $                 )
     $                 / ( photo_demeth + bio_red_demeth )
#endif
#endif

#ifdef Hg_Anthro_EF
                  nyear_realtime = nyear - 10000 + 1850

                  i_anthropocene = 0
                  if( nyear_realtime .GE. 1851
     $                 .AND. nyear_realtime .LE. 2100
     $                 ) then
                     i_anthropocene = 1
#ifdef Hg_Anthro_Hangover
                  else if( nyear_realtime .GT. 2100 ) then
                     i_anthropocene = 2
#endif
                  endif
#endif

                  flux_alphas = 0.d0
#ifdef Hg_Deposition_Frac
#ifdef Hg_Anthro_EF
                  if( i_anthropocene .EQ. 1 ) then
                     flux_alphas( i2P, i202 ) = -0.5d0 ! sun 2016 GOM/PBM today
                     flux_alphas( i0, i202 )  = +0.3d0 ! GEM
                     flux_alphas( i2P, i199 ) = +0.45d0
                     flux_alphas( i0, i199 )  = -0.15d0
                  else
                     flux_alphas( i2P, i202 ) = -0.2d0 ! sun and amos ms
                     flux_alphas( i0, i202 )  =  0.0d0
                     flux_alphas( i2P, i199 ) =  0.4d0
                     flux_alphas( i0, i199 )  = -0.1d0
                  endif
#else
                  flux_alphas( i2P, i202 ) = -0.2d0 ! sun and amos ms
                  flux_alphas( i0, i202 )  =  0.0d0
                  flux_alphas( i2P, i199 ) =  0.4d0
                  flux_alphas( i0, i199 )  = -0.1d0
#endif  /* Hg_Anthro_EF */
                  flux_alphas( i2P, i200 ) =  0.2d0
                  flux_alphas( i0, i200 )  =  0.08d0
#endif  /* Hg_Deposition_Frac */

                  do iFrom = 1, 4
                     do iTo = 1, 4
                        epsilon_202( iFrom, iTo ) = 1.d0
     $                    + ( mdf_alpha( iFrom, iTo )
     $                      ) / 1.d3
                        epsilon_199( iFrom, iTo ) = 1.d0
     $                    + ( mdf_alpha( iFrom, iTo )
     $                      / Hg_Mass_Dep_202_199
     $                      + mif_199_alpha( iFrom, iTo )
     $                      )
     $                    / 1.d3
                        epsilon_200( iFrom, iTo ) = 1.d0
     $                    + ( mdf_alpha( iFrom, iTo )
     $                      / Hg_Mass_Dep_202_200
     $                      ) / 1.d3
                        rate_199( iFrom, iTo ) =
     $                    rate_constants( iFrom, iTo)
     $                    * epsilon_199( iFrom, iTo )
                        rate_202( iFrom, iTo ) =
     $                       rate_constants( iFrom, iTo )
     $                       * epsilon_202( iFrom, iTo )
                        rate_200( iFrom, iTo ) =
     $                       rate_constants( iFrom, iTo )
     $                       * epsilon_200( iFrom, iTo )
                     enddo
                  enddo

c              acts as a nonconservative top boundary condition,
c                 alters the hg_tot values in k=1

                  fluxes = 0.d0
                  if( k .EQ. 1 ) then

                     fluxes(i2P, i198) =
     $                    Hg_2P_Atm_Dep_Rate

                     fluxes(i0, i198) =
     $                    hg_0_atm_dep_rate

#ifdef Hg_Anthro_EF
                     if( i_anthropocene .EQ. 1 ) then
                        fluxes(i2P, i198) = fluxes(i2P, i198)
     $                       * ( 1.d0 + hg_anthro_ef )
                        fluxes(i0, i198) = fluxes(i0, i198)
     $                       * ( 1.d0 + hg_anthro_ef )
#ifdef Hg_Anthro_Hangover
                     else if( nyear_realtime .GT. 2010 ) then
                        fluxes(i2P, i198) = fluxes(i2P, i198)
     $                       * ( 1.d0
     $                         + hg_anthro_ef
     $                         * exp( -
     $                             ( nyear_realtime - 2010 )
     $                             / 1.d3
     $                             )
     $                           )
                        fluxes(i0, i198) = fluxes(i0, i198)
     $                       * ( 1.d0
     $                         + hg_anthro_ef
     $                         * exp( -
     $                             ( nyear_realtime - 2010 )
     $                             / 1.d3
     $                             )
     $                           )
#endif
                     endif
#endif

                     do iSpec = 1, 4
                        do iIsotope = 2, 4
                           fluxes(iSpec, iIsotope) =
     $                          fluxes( iSpec, 1 )
     $                          * ( 1.d0
     $                            + flux_alphas( iSpec, iIsotope )
     $                              / 1000.d0 )
c                           write(6,*) iSpec, iIsotope,
c     $                          fluxes(iSpec, iIsotope),
c     $                          fluxes(1, iIsotope)
                        enddo
                        fluxes(iSpec,i199) = fluxes(iSpec,i199)
     $                          * ( 1.d0
     $                            + flux_alphas( iSpec, i202 )
     $                              / Hg_Mass_Dep_202_199
     $                              / 1000.d0 )
                        fluxes(iSpec,i200) = fluxes(iSpec,i200)
     $                          * ( 1.d0
     $                            + flux_alphas( iSpec, i202 )
     $                              / Hg_Mass_Dep_202_200
     $                              / 1000.d0 )
                     enddo
                     
#ifdef Parm_Basin
                     if(ibasin(i,j) .EQ. ibasin_deposition) then
                        fluxes(i2P,:) = fluxes(i2P,:)
     $                       * 2.d0
                     endif
#endif



c     base isotope 198


                     call load_surface_a( rate_constants,
     $                    fluxes(1,i198),
     $                    a, b )
                     hg_deposition(i,j) = fluxes(i2P, i198)
     $                    + fluxes(i0, i198)

                     call gaussj(a, 4, 4, b, 1, 1)

c                     write(6,*) b

                     hg_2p(i,j,1) = b(i2P)
                     hg_0(i,j,1) = b(i0)
                     hg_mm(i,j,1) = b(iMM)
                     hg_dm(i,j,1) = b(iDM)

                     hg_0_degassing(i,j) = - Hg_0(i,j,1)
     $                    * rate_constants( i0, i0 )
                     hg_dm_degassing(i,j) = - hg_dm(i,j,1)
     $                    * rate_constants( iDM, iDM )


c     mass 199 MIF

                     call load_surface_a( rate_199, fluxes(1,i199),
     $                    a, b ) 

                     call gaussj(a, 4, 4, b, 1, 1)
                  
                     hg_2p_199(i,j,1) = b(i2P)
                     hg_0_199(i,j,1) = b(i0)
                     hg_mm_199(i,j,1) = b(iMM)
                     hg_dm_199(i,j,1) = b(iDM)
                  

c     mass 202 MDF

                     call load_surface_a( rate_202, fluxes(1,i202),
     $                    a, b )
                  
                     call gaussj(a, 4, 4, b, 1, 1)
                  
                     hg_2p_202(i,j,1) = b(i2P)
                     hg_0_202(i,j,1) = b(i0)
                     hg_mm_202(i,j,1) = b(iMM)
                     hg_dm_202(i,j,1) = b(iDM)

c     mass 200 MIF
                     
                     call load_surface_a( rate_200,
     $                    fluxes(1,i200),
     $                    a, b )  
                  
                     call gaussj(a, 4, 4, b, 1, 1)
                  
                     hg_2p_200(i,j,1) = b(i2P)
                     hg_0_200(i,j,1) = b(i0)
                     hg_mm_200(i,j,1) = b(iMM)
                     hg_dm_200(i,j,1) = b(iDM)

#ifdef DebugIsotopes
                     call calc_hg_deltas(
     $                    hg_2p(i,j,1),
     $                    hg_2p_199(i,j,1),
     $                    hg_2p_200(i,j,1),
     $                    hg_2p_202(i,j,1),
     $                    d199,d200,d202,capD199,capD200)
                     write(6,"(5f12.2)") d199,d200,d202,capD199,capD200
#endif

#ifdef Hg_Subsurface_Speciation

                  else          ! subsurface partitions hg_tot into components

c     mass 198 (base)
                     call load_subsurface_a( rate_constants, a, b )
                     call gaussj(a, 3, 4, b, 1, 1)
                     call unpack_subsurface_b( hg_tot(i,j,k), b,
     $                    hg_2p(i,j,k), hg_0(i,j,k), 
     $                    hg_mm(i,j,k), hg_dm(i,j,k) )

c     mass 200 
                     call load_subsurface_a( rate_200, a, b )
                     call gaussj(a, 3, 4, b, 1, 1)
                     call unpack_subsurface_b( hg_200_tot(i,j,k), b,
     $                    hg_2p_200(i,j,k), hg_0_200(i,j,k), 
     $                    hg_mm_200(i,j,k), hg_dm_200(i,j,k) )
                     
c     mass 199 MIF
                     call load_subsurface_a( rate_199, a, b )
                     call gaussj(a, 3, 4, b, 1, 1)
                     call unpack_subsurface_b( hg_199_tot(i,j,k), b,
     $                    hg_2p_199(i,j,k),
     $                    hg_0_199(i,j,k), hg_mm_199(i,j,k),
     $                    hg_dm_199(i,j,k) )

c     mass 202 MDF
                     call load_subsurface_a( rate_202, a, b )
                     call gaussj(a, 3, 4, b, 1, 1)
                     call unpack_subsurface_b( hg_202_tot(i,j,k), b,
     $                    hg_2p_202(i,j,k),
     $                    hg_0_202(i,j,k), hg_mm_202(i,j,k),
     $                    hg_dm_202(i,j,k) )

#endif /* Hg_Subsurface_Speciation */
                  
                  endif         ! k .eq. 1 or not

               enddo

            endif       ! prorca .gt. 0
         enddo
      enddo


c#ifdef Hg_Advection
c     the component species have been set, update the totals in surf ocn
      do iT = 0, 3
c#define Hg_Hack_Surface
#ifdef Hg_Hack_Surface
         ca(:,:,1,7+iT) = 1.d-12       ! hg_tot
#else
         ca(:,:,1,7+iT) =        ! hg_tot
     $          ca(:,:,1,11+iT*4)  ! hg_2p
     $        + ca(:,:,1,12+iT*4)  ! hg_mm
     $        + ca(:,:,1,13+iT*4)  ! hg_dm
     $        + ca(:,:,1,14+iT*4)  ! hg_0
#endif
      enddo
c#endif

#endif /* Hg_Deposition */

#ifdef Hg_Sinking

c     hg_2P binding to poc
      DO j=jl1,jle
         DO i=1,ie
            do k=1,ke
               if(prorca(i,j) .GT. 0.d0 .AND.
     $            ddz(i,j,k) .GT. 1.d0) then
                  hg_2P_bound(i,j,k) = hg_2P(i,j,k)
     $                 * ( 1.d0 -
     $                     1 /
     $                     ( hg_2p_binding_constant
     $                     * poc_inv(i,j,k)
     $                          * 12.d0 / 1000.d0  ! kg / l (really)
     $                     + 1
     $                     )
     $                   )
                  hg_2P_202_bound(i,j,k) = hg_2P_202(i,j,k)
     $                 * ( 1.d0 -
     $                     1 /
     $                     ( hg_2p_binding_constant
     $                     * poc_inv(i,j,k)
     $                          * 12.d0 / 1000.d0  ! kg / l (really)
     $                     + 1
     $                     )
     $                   )
#ifdef Hg_Particles_Fractionation
     $                 * ( 1.d0
     $                   + mdf_alpha( i2P, i2P )
     $                   / 1000.d0
     $                   ) 
#endif
                  hg_2P_199_bound(i,j,k) = hg_2P_199(i,j,k)
     $                 * ( 1.d0 -
     $                     1 /
     $                     ( hg_2p_binding_constant
     $                     * poc_inv(i,j,k)
     $                          * 12.d0 / 1000.d0  ! kg / l (really)
     $                     + 1
     $                     )
     $                   )
#ifdef Hg_Particles_Fractionation
     $                 * ( 1.d0
     $                   + mdf_alpha( i2P, i2P )
     $                   / Hg_Mass_Dep_202_199
     $                   / 1000.d0 )
#endif
                  hg_2P_200_bound(i,j,k) = hg_2P_200(i,j,k)
     $                 * ( 1.d0 -
     $                     1 /
     $                     ( hg_2p_binding_constant
     $                     * poc_inv(i,j,k)
     $                          * 12.d0 / 1000.d0  ! kg / l (really)
     $                     + 1
     $                     )
     $                   )
#ifdef Hg_Particles_Fractionation
     $                 * ( 1.d0
     $                   + mdf_alpha( i2P, i2P )
     $                   / Hg_Mass_Dep_202_200
     $                   / 1000.d0 )
#endif
               endif
            enddo
         enddo
      enddo

c     hg_2P sinking fluxes
      hg_2p_global_sinking_flux = 0.d0
      hg_2p_global_sed_flux = 0.d0
      hg_2p_sinking_src = 0.d0
      DO j=jl1,jle
         DO i=1,ie
            do k=1,ke
               if(prorca(i,j) .GT. 0.d0) then
                  if( ddz(i,j,k) .GT. 1.d0) then

                     hg_2P_sinking_flux(i,j,k) =
     $                    hg_2P_bound(i,j,k) ! about 1e-13 m/L
     $                    * 1.d3 ! mol/m3
     $                    * hg_sinking_rate ! m/yr gives mol/m2yr
                     hg_2P_202_sinking_flux(i,j,k) =
     $                    hg_2P_202_bound(i,j,k)
     $                    * 1.d3
     $                    * hg_sinking_rate ! m/yr gives mol/m2yr
                     hg_2P_199_sinking_flux(i,j,k) =
     $                    hg_2P_199_bound(i,j,k)
     $                    * 1.d3
     $                    * hg_sinking_rate ! m/yr gives mol/m2yr
                     hg_2P_200_sinking_flux(i,j,k) =
     $                    hg_2P_200_bound(i,j,k)
     $                    * 1.d3
     $                    * hg_sinking_rate ! m/yr gives mol/m2yr

                     if( k .EQ. ke ) then
                        hg_sediment_flux(i,j) =  ! mol/m2yr
     $                       hg_2p_sinking_flux(i,j,k)
                     endif
                  else if( ddz(i,j,k-1) .GT. 1.d0) then
                     hg_sediment_flux(i,j) =
     $                    hg_2p_sinking_flux(i,j,k-1)
                  endif

               endif
            enddo
         enddo
      enddo

      hg_particle_lifetime = 0.d0

c     poc release of hg_2P alters the total Hg pools
      DO j=jl1,jle
         DO i=1,ie
            if(prorca(i,j) .GT. 0.d0) then
               hg_2p_particle_src(i,j,1) =
     $              - hg_2P_sinking_flux(i,j,1) ! mol/m2 yr
     $              / ( ddz(i,j,1)/1.d2 ) ! meters gives mol/m3 yr
     $              / 1.d3      ! mol/l yr
               
               do k=2,ke
                  if(ddz(i,j,k) .GT. 1.d0) then
                     hg_2p_particle_src(i,j,k) =
     $                   ( hg_2P_sinking_flux(i,j,k-1) ! mol/m2 yr
     $                   - hg_2P_sinking_flux(i,j,k) ! mol/m2 yr
     $                   )
     $                 / ( ddz(i,j,k)/1.d2 )         ! meters gives mol/m3 yr
     $                 / 1.d3                        ! mol/l yr, analogous to prorca
                     hg_tot(i,j,k) = hg_tot(i,j,k) ! mol/m
     $                 + hg_2p_particle_src(i,j,k)

                     hg_202_tot(i,j,k) = hg_202_tot(i,j,k) ! mol/m
     $                 + ( hg_2P_202_sinking_flux(i,j,k-1) ! mol/m2 yr
     $                   - hg_2P_202_sinking_flux(i,j,k) ! mol/m2 yr
     $                   )
     $                 / ( ddz(i,j,k)/1.d2 )         ! meters gives mol/m3 yr
     $                 / 1.d3                        ! mol/l yr
                     hg_199_tot(i,j,k) = hg_199_tot(i,j,k) ! mol/m
     $                 + ( hg_2P_199_sinking_flux(i,j,k-1) ! mol/m2 yr
     $                   - hg_2P_199_sinking_flux(i,j,k) ! mol/m2 yr
     $                   )
     $                 / ( ddz(i,j,k)/1.d2 )         ! meters gives mol/m3 yr
     $                 / 1.d3                        ! mol/l yr
                     hg_200_tot(i,j,k) = hg_200_tot(i,j,k) ! mol/m
     $                 + ( hg_2P_200_sinking_flux(i,j,k-1) ! mol/m2 yr
     $                   - hg_2P_200_sinking_flux(i,j,k) ! mol/m2 yr
     $                   )
     $                 / ( ddz(i,j,k)/1.d2 )         ! meters gives mol/m3 yr
     $                 / 1.d3                        ! mol/l yr
                  endif
               enddo

               do k=1,ke
                  if(ABS(hg_2p_particle_src(i,j,k)) .GT. 1.d-18) then
                     hg_particle_lifetime(i,j,k) = hg_tot(i,j,k)
     $                    / ABS(hg_2p_particle_src(i,j,k))
                  endif
               enddo

            endif
         enddo
      enddo

#endif /* Hg_Sinking */

c     save values to diagnose advective fluxes to surface layer
      hg_surf_tot_old = hg_tot(:,:,1)
      hg_199_surf_tot_old = hg_199_tot(:,:,1)
      hg_202_surf_tot_old = hg_202_tot(:,:,1)

c     diagnostics
      hg_tot_global = 0.d0
      DO j=jl1,jle
         DO i=1,ie
            do k=1,ke
               hg_tot_global = hg_tot_global
     $              + hg_tot(i,j,k) ! mol/l
            enddo
         enddo
      enddo

c     output
      icdf = 0
      write(6,*) "year", nyear, nyear_realtime
c      if( nyear_realtime .EQ. 0 ) then ! preanthro steady state
c         icdf = 1
c      endif
      if( nyear_realtime .EQ. 1850 ) then ! preanthro steady state
         icdf = 1
      endif
      if( nyear_realtime .EQ. 2010 ) then ! present day
         icdf = 1
      endif
      if( nyear_realtime .EQ. 2100 ) then ! 2100
         icdf = 1
      endif

      nyear_cdf = nyear_realtime

#ifdef Debug_Printout
      if( nyear .EQ. 2) then ! MOD(nyear,2 ) .EQ. 0 ) then
         icdf = 1
         nyear_cdf = nyear
      endif
#endif

c      icdf = 1

      if( icdf .EQ. 1) then
         nstp = nyear_cdf
         filename = 'hg.xxxxx'
         do ipos=8,4,-1
            idigit = mod(nstp,10)
            filename(ipos:ipos) = char(ichar('0') + idigit)
            nstp = nstp/10
         enddo
#ifdef Remember_Hg_2P_Binding_Constant
         filename = trim(filename) // '.Bind.'
         write(string_name,'(e9.3)') hg_2p_binding_constant
         filename = trim(filename) // trim(string_name)
#endif
#ifdef Parm_Hg_Sinking_Rate
         filename = trim(filename) // '.Sink.'
         write(string_name,'(e9.3)') hg_sinking_rate
         filename = trim(filename) // trim(string_name)
#endif
#ifdef Parm_Dry_Dep
         write(string_name,'(e9.3)') hg_0_atm_dep_frac
         filename = trim(filename) // '.DD.'
     $        // trim(string_name)
#endif
#ifdef Parm_Hg_Binding_Constant
         write(string_name,'(e9.3)') hg_2p_binding_constant
         filename = trim(filename) // '.Kd.'
     $        // trim(string_name)
#endif
#ifdef Parm_Basin
         write(string_name,'(i1.1)') ibasin_deposition
         filename = trim(filename) // '.Basin.'
     $        // trim(string_name)
#endif
#ifdef GooseFactor
         write(string_name,'(g7.2)') GooseFactor
         filename = trim(filename) // '.goose.'
     $        // trim(string_name)
#endif
#ifdef Remember_Hg_Anthro_EF
         write(string_name,'(e9.3)') Hg_Anthro_EF
         filename = trim(filename) // '.EF.'
     $        // trim(string_name)
#endif
#ifdef Remember_Basin
         write(string_name,'(i1)') ibasin_deposition
         filename = trim(filename) // '.Basin.'
     $        // trim(string_name)
#endif
         filename = trim(filename) //'.cdf'
         write(6,*) "writing netcdf ", filename
         call printout(filename)
c         call pools
      endif

      ipool = 0
c      if( nyear .LT. 0 ) then
         if( MOD(nyear,10) .EQ. 0 ) then
            ipool = 1
         endif
      if( ipool .EQ. 1 ) then
         CALL pools
      endif

      return
      end

      subroutine load_surface_a(rates, fluxes, a, b)

      real rates(4,4), fluxes(4), a(4,4), b(4)

      a = 0
      b = 0

      do i = 1, 4
         a(i,i) = a(i,i) - rates(i,i)
         b(i) = - fluxes(i)
         do j = 1, 4
            if( j .NE. i ) then
               a(i,i) = a(i,i) - rates( i, j ) ! diagonal sink terms
               a(i,j) = a(i,j) + rates( j, i )
            endif
         enddo
      enddo

c      b(i2P) = - Hg_2P_Atm_Dep_Rate 

      return
      end

      subroutine load_subsurface_a(rates, a, b)
c     assume Hg2+ = 1.0, find the other values

c                 Hg0       mm        dm

c Hg0 budget    | -K02      0         0    ||  Hg0  |   | -K20  |
c mm budget     | 0         -Km2-Kmd  Kdm  ||  mm   | = | -K2m  |
c dm budget     | 0         Kmd       -Kdm ||  dm   |   | -D2d  |

      real rates(4,4), a(4,4), b(4)

      a = 0
      b = 0
      do i = 1, 3
         do j = 1,4  ! needs the 4 so that loss of Hg0 to Hg2+ in diag term 
            if( i .NE. j ) then
               a( i, i ) = a( i, i ) - rates( i, j )
               a( i, j ) = a( i, j ) + rates( j, i )  ! a(:,4) unused anyway
            endif
         enddo
         b( i ) = - rates( i2P, i )
      enddo

      return
      end

      subroutine unpack_subsurface_b( hg_tot, b,
     $     hg_2p, hg_0, hg_mm, hg_dm )
      real b(3), hg_2p, hg_0, hg_mm, hg_dm

      totScale = 1.d0 + b(1) + b(2) + b(3)
      hg_2P = 1.d0 / totScale * hg_tot
      hg_0  = b(i0) / totScale * hg_tot
      hg_mm = b(iMM) / totScale * hg_tot
      hg_dm = b(iDM) / totScale * hg_tot

      return
      end


      SUBROUTINE gaussj(a,n,np,b,m,mp)
       
C        numerical recipes, pages 28-29

       PARAMETER (nmax=600)
       DIMENSION a(np,np), b(np,mp)
       DIMENSION ipiv(nmax)
       DIMENSION indxr(nmax), indxc(nmax)
       DO 11 j=1,n
         ipiv(j)=0
 11    CONTINUE
       DO 22 i=1,n
         big=0.
         DO 13 j=1,n
           IF(ipiv(j).NE.1) then
             DO 12 k=1,n
               IF(ipiv(k).EQ.0) then
                 IF(abs(a(j,k)).ge.big) then
                   big=abs(a(j,k))
                   irow=j
                   icol=k
                 ENDIF
               ELSE IF(ipiv(k).GT.1) then
                 PAUSE 'singular matrix'
               ENDIF
 12          CONTINUE
           ENDIF
 13      CONTINUE
         ipiv(icol)=ipiv(icol)+1
         IF(irow.NE.icol) then
           DO 14 l=1,n
             dum=a(irow,l)
             a(irow,l)=a(icol,l)
             a(icol,l)=dum
 14        CONTINUE
           DO 15 l=1,m
             dum=b(irow,l)
             b(irow,l)=b(icol,l)
             b(icol,l)=dum
 15        CONTINUE
         ENDIF
         indxr(i)=irow
         indxc(i)=icol
         IF(a(icol,icol).EQ.0.) PAUSE 'singular matrix'
         pivinv=1./a(icol,icol)
         a(icol,icol)=1.
         DO 16 l=1,n
           a(icol,l)=a(icol,l)*pivinv
 16      CONTINUE
         DO 17 l=1,m
           b(icol,l)=b(icol,l)*pivinv
 17      CONTINUE
         DO 21 ll=1,n
           IF(ll.NE.icol) then
             dum=a(ll,icol)
             a(ll,icol)=0.
             DO 18 l=1,n
               a(ll,l)=a(ll,l)-a(icol,l)*dum
 18          CONTINUE
             DO 19 l=1,m
               b(ll,l)=b(ll,l)-b(icol,l)*dum
 19          CONTINUE
           ENDIF
 21      CONTINUE
 22    CONTINUE
       DO 24 l=n,1,-1
         IF(indxr(l).NE.indxc(l)) then
           DO 23 k=1,n
             dum=a(k,indxr(l))
             a(k,indxr(l))=a(k,indxc(l))
             a(k,indxc(l))=dum
 23        CONTINUE
         ENDIF
 24    CONTINUE
       RETURN
       END


      subroutine calc_hg_deltas(c198,c199,c200,c202,
     $     d199,d200,d202,capD199,capD200)
      
      if( c198 .GT. 0.d0 ) then
         d199 = ( c199 / c198 - 1.d0 ) * 1000.d0
         d200 = ( c200 / c198 - 1.d0 ) * 1000.d0
         d202 = ( c202 / c198 - 1.d0 ) * 1000.d0
         capD199 = d199 - d202 / Hg_Mass_Dep_202_199
         capD200 = d200 - d202 / Hg_Mass_Dep_202_200
      endif

      return
      end
