#define AdjTemp
c#define TimeDepAdjTemp


      SUBROUTINE initia1

C**** *initia1* - initiates hor. velocities and geometrical variables
C     e. maier-reimer      mpi hamburg      88/07/01.

C     purpose.
C     --------
C          *initia1* initiates horizontal velocities, geometrical
C     variables (volumes, areas, lenghts)

C**   interface.
C     ----------
C          *call* *initia1*

C     method.
C     -------
C          -.

C     externals.
C     ----------
C          none.

C     reference.
C     ----------

C          stuiver, m., and h. a. pollach (1977)
C          discussion reporting of 14c DATA.
C          radiocarbon, vol. 19, no. 3, 355-363.


C*     variable    type    purpose.
C      --------    ----    --------

C      *br*        REAL    dummy variable for calculation of geogr. lati
C      *phi*       REAL    geogr. latitude [rad]
C      *bt*        REAL    mean total borate in seawater [moles]
C                          ([b(oh)3]+[b(oh)4])
C      *nords*     REAL    meridional index at southern bound of indus-
C                          trialized countries
C                          (it is assumed that north of latitude/merid. 
C                          nords the bulk of anthropogenic co2 is intrud
C                          into the atmosphere; other areas negelected)
C      *dl*        REAL    horizontal spacing in zonal direction
C                          between two grid points [cm]
C      *akb*       REAL    approximate equilibrium constant for
C                          reaction h2o+b(oh)3->h+ + b(oh)4-
C                          (1. dissoc. constant for boric acid)

C     -----------------------------------------------------------------
      INCLUDE 'parameter.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
      INCLUDE 'equivalence.include'
c      include 'common.archer'
      DIMENSION phirea(je)

C     -----------------------------------------------------------------
C*         1. set half precision constants
C             --- ---- --------- ---------

      zero=0.
      epsma=1.e-20
      fourth=0.25
      half=0.5
      one=1.
      two=2.

C     -----------------------------------------------------------------
C*         2. 14c decay constant in [s**-1] (stuiver and pollak, 1977)
C             --- ----- -------- ---------- -------- --- ------- -----

      deccon=1./(8267.*365.*86400.)

C     -----------------------------------------------------------------
C*         3. set diffusion coefficient for ocean tracer transport
C             (cf. SUBROUTINE advect) (cm**2/s)
C             ---- ---------- ------- ----------- ------ ---------

C      diff=10.00
       diff=100.00
       print*,'***diff=',diff

C     -----------------------------------------------------------------
C*         4. set time step [s]
C             --- ---- ---- ---

        dt=365.*86400.

C     -----------------------------------------------------------------
C*         5. calculate inverse of max. of index in zonal direction
C             --------- ------- -- ---- -- ----- -- ----- ---------

      zoanz=1./FLOAT(ie)

C     -----------------------------------------------------------------
C*         6. READ annual mean current field, pot. temp., salinity,  ,
C             convective adjustment (sum of annual convective events),
C             bottom depth at vector-/scalar points, layer thickness
C             at vector-/scalar points from tape37
C             -- -------------- ------ ---- -------- ----- -----------

C      READ(37,1001) u,v,(((w(i,j,k),i=1,ie),j=1,je),k=2,kep),
C    1   tem,sal,convad,deptu,deptp,ddu,ddz
C1001 FORMAT(5(1x,e14.8))
C check of current and thermohaline fields ***dirme1 begin
C     print*,'***dirme1 u nordatl'
C     DO 2001 j=1,35
C2001   WRITE(6,'(10(1x,e10.4))')(u(4,j,k),k=1,10)
C     print*,'***dirme1 v nordatl'
C     DO 2002 j=1,35
C2002   WRITE(6,'(10(1x,e10.4))')(v(4,j,k),k=1,10)
C     print*,'***dirme1 w nordatl'
C     DO 2003 j=1,35
C2003   WRITE(6,'(10(1x,e10.4))')(w(4,j,k),k=1,10)
C     print*,'***dirme1 tem nordatl'
C     DO 2004 j=1,35
C2004   WRITE(6,'(10(1x,e10.4))')(tem(4,j,k),k=1,10)
C     print*,'***dirme1 sal nordatl'
C     DO 2005 j=1,35
C2005   WRITE(6,'(10(1x,e10.4))')(sal(4,j,k),k=1,10)
C     print*,'***dirme1 convad nordatl'
C     DO 2006 j=1,35
C2006   WRITE(6,'(10(1x,e10.4))')(convad(4,j,k),k=1,10)
C     print*,'***dirme1 ddu nordatl'
C     DO 2007 j=1,35
C2007   WRITE(6,'(10(1x,e10.4))')(ddu(4,j,k),k=1,10)
C     print*,'***dirme1 ddz nordatl'
C     DO 2008 j=1,35
C2008   WRITE(6,'(10(1x,e10.4))')(ddz(4,j,k),k=1,10)
C     print*,'***dirme1 deptu nordatl'
C     DO 2009 j=1,35
C2009   WRITE(6,'(1x,e10.4)')deptu(4,j)
C     print*,'***dirme1 deptp nordatl'
C     DO 2010 j=1,35
C2010   WRITE(6,'(1x,e10.4)')deptp(4,j)
C check of current and thermohaline fields ***dirme1 END
      CALL reacir
C     DO 5381 k=1,kep
C       print*,'k intu intw ',k,intu(k),intw(k)
C5381 CONTINUE
      weven=0.
      wodd=0.
      wabsu=0.
      DO 7701 k=2,kep
      DO 7701 j=1,je
      DO 7701 i=1,ie
        IF(MOD(j,2).EQ.0)then
          weven=weven+w(i,j,k)
        ELSE
          wodd=wodd+w(i,j,k)
        ENDIF
        wabsu=wabsu+abs(w(i,j,k))
 7701 CONTINUE
c      print*,'weven= ',weven
c      print*,'wodd=  ',wodd
c      print*,'wabsu= ',wabsu
      umin=1.e10
      umax=-1.e-9
      vmin=1.e10
      vmax=-1.e-9
      wmin=1.e10
      wmax=-1.e-9
      conmin=1.e10
      conmax=-1.e-9
      DO 1002 k=1,ke
      DO 1002 j=1,je
      DO 1002 i=1,ie
        IF(u(i,j,k).GT.umax)umax=u(i,j,k)
        IF(u(i,j,k).LT.umin)umin=u(i,j,k)
        IF(v(i,j,k).GT.vmax)vmax=v(i,j,k)
        IF(v(i,j,k).LT.vmin)vmin=u(i,j,k)
        IF(k.NE.1)then
          IF(w(i,j,k).GT.wmax)wmax=w(i,j,k)
          IF(w(i,j,k).LT.wmin)wmin=w(i,j,k)
        ENDIF
        IF(convad(i,j,k).GT.conmax)conmax=convad(i,j,k)
        IF(convad(i,j,k).LT.conmin)conmin=convad(i,j,k)
 1002 CONTINUE
c      print*,'***umin umax ',umin,umax
c      print*,'***vmin vmax ',vmin,vmax
c      print*,'***wmin wmax ',wmin,wmax
c      print*,'***conmin conmax ',conmin,conmax
      conmi1=1.e10
      conma1=-1.e-9
      DO 1003 j=1,je
      DO 1003 i=1,ie
        IF(convad(i,j,1).GT.conmax)conma1=convad(i,j,1)
        IF(convad(i,j,1).LT.conmin)conmi1=convad(i,j,1)
 1003 CONTINUE
c      print*,'***conmi1 conma1 ',conmi1,conma1

C     -----------------------------------------------------------------
C*         7. set horizontal velocities 0 near north pole
C             --- ---------- ---------- - ---- ----- ----

C     DO 1963 k=1,ke
C     DO 1963 j=1,2
C     DO 1963 i=1,ie
C     u(i,j,k)=0.
C     v(i,j,k)=0.
C1963  CONTINUE

C     -----------------------------------------------------------------
C*         8. initiate ocean layer volumes and areas represented by
C             grid points
C             ---- --------- ----- ------- --- ----- ----------- --

      DO 901 k=1,ke
      volum(k)=0.
      DO 901 j=1,je
      DO 901 i=1,ie
      dzdl(i,j,k)=0.
901   CONTINUE

C     -----------------------------------------------------------------
C*        11. horizontal spacing in merdional direction between
C             two grid points and respective inverse value
C             --- ---- ------ --- ---------- ------- ----------

C     dphi=637104000.*2.*4.*ATAN(1.)/real(ie)
C     print*,'***dphi=',dphi
C     dpin=1./dphi

C     -----------------------------------------------------------------
C*         9. initiate horizontal spacing between two grid points in
C             zonal direction (dla), land/sea distribution (rwat),
C             and area represented by grid points (dzdl)
C             --- ---- ----------- -- ---- --------------- ---------

C     DO 902 j=jl1,jle
      DO 902 j=1,je
C     br=real((jle-jl1+1)/2)+0.5-real(j-jl1+1)
C     phi=4.*ATAN(1.)*br/real(jle-jl1+1)
C     dla(j)=dphi*COS(phi)
C     print*,'***dla(',j,')=',dla(j)
Cc    br=36.5-j
Cc    phi=4.*ATAN(1.)*br/72.
Cc    dla(j)=55500000.*COS(phi)
      DO 902 i=1,ie
      rwat(i,j)=0.
      IF(deptp(i,j).GT.one) rwat(i,j)=one
902   CONTINUE
C***dphi -> dpin, dla(phi) as used for veloci, pa2010m
      DO 903 j=1,je
        READ(36,'(20x,i3,1x,e18.14,6x,f16.4,2x,f10.1)')
     .      jre,phirea(j),dla(j),dphi
        IF(j.LT.jl1.or.j.GT.jle)then
          phirea(j)=0.
          dla(j)=0.
        ENDIF
        dla(j)=dla(j)*100.
        dphi=dphi*100.
        phi=phirea(j)
        pi=4.*ATAN(1.)
        phideg(j)=phi*180./pi
C       print*,'***dphila***'
C       WRITE(6,'(20x,i3,1x,f18.10,6x,f16.4,2x,f10.1)')
C    *    j,phi,dla(j),dphi
        IF(jre.NE.j) STOP 'jre.NE.j initia1'
  903 CONTINUE
      dpin=1./dphi
C     print*,'after dphila  dphi dpin ',dphi, dpin

      DO 1902 k=1,ke
C new in crun66b
      DO 1902 j=jl1,jle
C     DO 1902 j=1,je
      DO 1902 i=1,ie
      dzdl(i,j,k)=ddz(i,j,k)*dla(j)
1902  CONTINUE

C     -----------------------------------------------------------------
C*        10. initiate vertical velocities (calculated newly in
C             main program)
C             ---- ------------ ---------- ----------- ----- --

      DO 922 k=2,ke
      DO 922 j=1,je
      DO 922 i=1,ie
        IF(ddz(i,j,k).LT.1.)w(i,j,k)=0.
  922 CONTINUE
      DO 921 j=1,je
      DO 921 i=1,ie
      w(i,j,kep)=zero
921   CONTINUE

C     -----------------------------------------------------------------
C*        12. set conversion factor giga tons -> ppm
C             --- ---------- ------ ---- ---- -- ---

      gtippm=290.*1.e-15/620.

C     -----------------------------------------------------------------
C*        13. set mean total borate in sea water [moles]
C             --- ---- ----- ------ -- --- ----- -------

      bt=0.409e-3

C     -----------------------------------------------------------------
C*        14. initiate convective adjustment
C             -------- ---------- ----------

C     DO 4001 j=jl1,jle
C     DO 4001 i=1,ie
C       IF(tem(i,j,1).le.one) convad(i,j,2)=one
C4001 CONTINUE
      DO 4000 k=2,ke
      DO 4000 j=jl1,jle
      DO 4000 i=1,ie
      convad(i,j,k)=convad(i,j,k)*
     .  (dzdl(i,j,k)+dzdl(i,j,k-1))
4000  CONTINUE

C     -----------------------------------------------------------------
C*        15. initiate area of earth's surface, zonal spacing between
C             grid points, land/sea, zones of anthropogenic co2 input
C             into the atmosphere
C             ---- --- ------------- ----- -- ------------- --- -----

C*        15.1 initiate areas
      fla=0.
      wafl=0.
      erdof=0.

C*        15.2 set southern boundary (merdional index) of major
C              industrialized countries
      nords=25

C*        15.3 calculate horizontal spacing between two grid points
C              in zonal direction at center of grid points (dla, dlll)
C              and half the way north (dlro) and south (dlru),
C              identifier for land/sea distribution (rwat), indus-
C              trialized zones with anthropogenic co2 emission (prodzo),
C              areas covered by land (fla), with water (wafl), and total
C              area of globe (erdof)
      DO 1 j=jl1,jle
C     br=real((jle-jl1+1)/2)+0.5-real(j-jl1+1)
C     phi=4.*ATAN(1.)*br/real(jle-jl1+1)
C     br=36.5-FLOAT(j)
C     phi=3.1415926535*br/72.0
C     dl=dphi*COS(phi)
C     dla(j)=dl
      phi=phirea(j)
C     print*,'***do1 initia1  j dla(j) phi',j,dla(j),phi
C     IF(j.ge.2) dlro(j)=half*(dla(j-1)+dla(j))/dla(j)
C     IF(j.ge.2) dlru(j-1)=half*(dla(j)+dla(j-1))/dla(j-1)
      IF(j.ge.jl1+1) dlro(j)=half*(dla(j-1)+dla(j))/dla(j)
      IF(j.ge.jl1+1) dlru(j-1)=half*(dla(j)+dla(j-1))/dla(j-1)
C     dli(j)=1./dl
      dli(j)=1./dla(j)
      DO 111 i=1,ie
      prodzo(i,j)=0.
      IF(deptp(i,j).GT.1.) rwat(i,j)=1.
      IF(deptp(i,j).EQ.0.AND.j.le.nords) prodzo(i,j)=1.
      IF(j.le.nords.AND.
     .  deptp(i,j).le.1)fla=fla+dphi**2*COS(phi)
      IF(deptp(i,j).GT.1) wafl=wafl+dla(j)*dphi
      erdof=erdof+dphi**2*COS(phi)
      dlll(i,j)=dla(j)
111   CONTINUE
1     CONTINUE
      DO 2256 j=1,je
      DO 2256 i=1,ie
      dlll(i,j)=dla(j)
 2256 CONTINUE

C     -----------------------------------------------------------------
C*        16. set approximate 1. dissociation const. for boric acid
C             --- ----------- -- ------------ ------ --- ----- ----

      akb=0.1881e-8

C     -----------------------------------------------------------------
C*        17. final initiation of ocean layer volumes and areas
C             represented by grid points
C             ----------- -- ---- ----------- ------- --- -----

C*        17.1 where ice no wet point
      DO 4004 j=jl1,jle
      DO 4004 i=1,ie
        IF(thicic(i,j).GT.0.01)rwat(i,j)=0.
C       IF(convad(i,j,2).GT.0.01)rwat(i,j)=1.
 4004 CONTINUE
      DO 16511 k=1,ke
      DO 16511 j=1,je
      DO 16511 i=1,ie
      volum(k)=volum(k)+ddz(i,j,k)*dla(j)*dphi
C     dzdl(i,j,k)=ddz(i,j,k)*dla(j)
16511 CONTINUE

C     -----------------------------------------------------------------
C*        18. set conversion factor ppm -> moles/cm**2
C             --- ---------- ------ --- -- -----------

      atmor=33.e-6
C     -----------------------------------------------------------------
C*        19. divide total surface of earth by two to account for
C             overlapping of grid point boxes
C             ----------- -- ---- ----- ------

      erdof=erdof*0.5

C     -----------------------------------------------------------------
C*        20. divide relevant land area two to account for
C             overlapping grid point areas
C             ----------- ---- ----- ------ -- ------- ---

      fla=fla*0.5

C     -----------------------------------------------------------------
C*        20. divide area covered with water by two to account for
C             overlapping grid point areas
C             ----------- ---- ----- ------- -- --- -- ------- ---

      wafl=wafl*0.5
c      print*,'***erdof=',erdof
c      print*,'***fla=',fla
c      print*,'***wafl=',wafl

      DO 7023 j=1,jl1-1
      DO 7023 i=1,ie
        rwat(i,j)=0.
 7023 CONTINUE
      DO 7024 j=jle+1,je
      DO 7024 i=1,ie
        rwat(i,j)=0.
 7024 CONTINUE

      DO 5629 j=1,je
      DO 5629 i=1,ie
C       WRITE(41,'(''i j dlll dzdl   '',2i3,2(1x,e12.6))')
C    1     i,j,dlll(i,j),dzdl(i,j)
 5629 CONTINUE

C     -----------------------------------------------------------------
C*        xx. set surface maximum surface layer thickness
C             --- ------- ------- ------- ----- ---------

      tobox=dzw(1)
C     -----------------------------------------------------------------
C*        xx. read MONITO file, which differentiates ocean basins
C             
      do j = jl1, jle
         read(17,1234) (ibasin(i,j), i=1, ie)
      enddo
 1234 format(1x,72I1)
C     


      RETURN
      END
      SUBROUTINE initia2

C**** *initia2* - initiates biological and chemical variables

C     e. maier-reimer      mpi hamburg      88/07/01.

C     purpose.
C     --------
C          *initia2* initiates biological and chemical variables


C**   interface.
C     ----------
C          *call* *initia2*

C     method.
C     -------
C          -.

C     externals.
C     ----------
C          *bioini*  - SUBROUTINE to initiate biological fields
C          *chemin*  - SUBROUTINE to put chemical constants
C          *inibil*  - SUBROUTINE to initiate balances

C     reference.
C     ----------
C          (see subroutines bioini and chemin.)

C*     variable    type    purpose.
C      --------    ----    --------

C      *avogad*    REAL    avogadro's constant, number of atoms (molecul
C                          in one mole of corresp. substance
C      *dphi*      REAL    horizontal meridional spacing between
C                          two grid points [cm]
C      *fla*       REAL    area of land, where bulk of anthropogenic
C                          co2 is released (ca. north of 25 deg n)
C      *year*      REAL    number of seconds of one year
C      *surlay*    REAL    hydrostatic pressure exceeded by ocean surfac
C                          layer [bar]
C      *eli*       REAL    dummy variable for converting tridiagonal
C                          matrix into upper triangle matrix (atmospheri
C                          diffusion of co2)

C     -----------------------------------------------------------------
      INCLUDE 'parameter.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
      INCLUDE 'equivalence.include'
c      print*,' initia2 entered '

C     -----------------------------------------------------------------
C*         1. set number of atoms (molecules) per mole
C             --- ------ -- ----- ----------- --- ----

      avogad=6.023e23

C     -----------------------------------------------------------------
C*         3. initiate atmospheric input from anthropogenic sources
C             -------- ----------- ----- ---- ------------- -------

      totin=0.

C     -----------------------------------------------------------------
C*         5. set number of seconds of one year
C             --- ------ -- ------- -- --- ----

      year=365.242*86400.

C     -----------------------------------------------------------------
C*         6. set hydrostatic pressure [bar] exerted by surface layer
C             --- ----------- -------- ----- ------- -- ------- -----

      surlay=dzw(1)/1000.
c      print*,'surlay=',surlay
C     surlay=11.25

C     -----------------------------------------------------------------
C*         7. volrat: conversion factor for atmospheric co2 concen-
C                     tration from ppm in moles/l in surface layer
C                     atmor= 33e-6 = 33 micromoles/cm**2
C                     surlay= 11.25 bar
C             ------- ------- ----- --- -------------------- ------
      volrat=atmor/surlay
c      print*,' volrat',atmor,surlay,volrat,dt,dphi
2     CONTINUE

C     -----------------------------------------------------------------
C*         8. initiate tridiagonal matrix for meridional atmospheric
C             co2-transport by diffusion

C td(1,2)*at(1) -td(1,3)*at(2)      0 ......................0  = at(1)ol
C-td(2,1)*at(1)  td(2,2)*at(2) -td(2,3)*at(3)     0..........  = at(2)ol
C  0                                               .        .
C  ..                                               .       .
C  . .                                               .      .
C  .  .                                               .     0
C  .   .                                               .    .
C  .    .                                                .  .
C  .     .                                                . .
C  .      .                                                 0
C  .......0 -td(71,1)*at(70)  td(71,2)*at(71) -td(71,3)*at(72) = at(71)o
C  0................ 0       -td(72,1)*at(71)  td(72,2)*at(72) = at(72)o

C     at(j) = atmospheric concentration
C     at(j)old = atmospheric concentration (previous time level)
C     td(j,1...3) = coefficients of matrix (containing diffusion coeff.)

C   principal scheme:  (with diffusion coefficients termed k(j))

C   at(j) = at(j)old+k(j+1)*at(j+1)+k(j-1)*at(j-1)-at(j)*(k(j-1)+k(j+1))

C   --------------------------------------------------------------------

C*         8.1 set coefficients of matrix with diffusion coefficients
C              (''uff'') as a function of latitude according to the
C              scheme shown above
      DO 50 j=jl1,jle
C       print*,'***preindu DO 50 j uff dlro dlru ',
C    *   j,uff(j),dlro(j),dlru(j)
      td(j,1)=0.
      td(j,3)=0.
      td(j,2)=1.
      IF(j.EQ.jl1) GO TO 51
      td(j,2)=td(j,2)+dlro(j)*uff(j-1)
      td(j,1)=-dlro(j)*uff(j-1)
51    IF(j.EQ.jle) GO TO 50
      td(j,2)=td(j,2)+uff(j)*dlru(j)
      td(j,3)=-uff(j)*dlru(j)
50    CONTINUE

C*         8.2 convert coefficients td(j,1) and td(j,2) to
C              change the tridiagonal matrix into an upper
C              triangle matrix
      jstart=jl1+1
      DO 52 j=jstart,jle
      eli=td(j,1)/td(j-1,2)
      td(j-1,1)=eli
      td(j,2)=td(j,2)-eli*td(j-1,3)
52    CONTINUE

C     -----------------------------------------------------------------
C*         9. initiate biological variables
C             -------- ---------- ---------

      CALL bioini
C     -----------------------------------------------------------------
C*        10. initiate chemical constants (solubil., dissoc. const. etc.
C             -------- -------- --------- ---------- ------- ------ ----

c      print*, ' before chemin '
      CALL chemin

C     -----------------------------------------------------------------
C*        11. initiation of concentration at new time step
C             ---------- -- ------------- -- --- ---- ----

      DO 8321 iv=1,nv
      DO 8321 k=1,ke
      DO 8321 j=1,je
      DO 8321 i=1,ie
      cn(i,j,k,iv)=ca(i,j,k,iv)
8321  CONTINUE
      RETURN
      END

      SUBROUTINE bioini
      INCLUDE 'parameter.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
      INCLUDE 'common.hg'
      INCLUDE 'equivalence.include'

C**** *bioini* - initiates biological variables

C     e. maier-reimer      mpi hamburg      88/07/01.

C     purpose.
C     --------
C          *bioini* initiates biological variables


C**   interface.
C     ----------
C          *call* *bioini*

C     method.
C     -------
C          -.

C     externals.
C     ----------
C          none.

C     reference.
C     ----------

C          degens, e.t, s. kempe, and a. spitzy (1984)
C          carbon dioxide: a biogeochemical portrait.
C          in: the handbook of environmental chemistry, volume 1/
C          part c, o. hutzinger, ed., springer-verlag, berlin,
C          heidelberg, pp. 127-215.

C          dugdale. r.c. (1967)
C          nutrient limitation in the sea: dynamics, identification
C          and significance.
C          limnology and oceanography, vol.12, 685-695.

C          parsons, t.r., and m. takahashi (1973)
C          biological oceanographic processes.
C          pergamon press, 186 pp.

C          takahashi, t., w.s. broecker, and s. langer (1985)
C          redfield ratio based on chemical DATA from isopycnal
C          surfaces.
C          journal of geophysical research, 90(c4), 6907-6924.


C*     variable    type    purpose.
C      --------    ----    --------

C      *dm0(ke)*   REAL    part of newly produced biogenic poc
C                          remaining in the relevant layer (for water
C                          column with max. possible bottom depth)
C      *dc0(ke)*   REAL    part of newly produced biogenic caco3 particl
C                          remaining in the relevant layer (for water
C                          column with max. possible bottom depth)
C      *ds0(ke)*   REAL    part of newly produced biogenic sio4 particle
C                          remaining in the relevant layer (for water
C                          column with max. possible bottom depth)
C                          (not used in this model version)
C      *pendeo*    REAL    penetration depth of soft tissue [cm],
C                          e-folding depth for remaining part of
C                          newly formed biogenic poc in water column
C      *pendec*    REAL    penetration depth of caco3 hard parts [cm],
C                          e-folding depth for remaining part of newly f
C                          med biogenic caco3 particles in water column
C      *ke1*       INTEGER max. index in vertical direction minus one (k
C      *tobbb*     REAL    thickness of uppermost layer [cm]
C      *tob*       REAL    layer thickness betw. w-points, upper layer, 
C      *tun*       REAL    layer thickness betw. w-points, lower layer,
C                          (next below that with tob) [cm]
C      *drif*      REAL    fraction of newly formed biogenic poc that do
C                          not fall immediately to the bottom
C      *rro*       REAL    remaining fraction of newly formed biogenic p
C      *dric*      REAL    fraction of newly formed biogenic caco3 par-
C                          ticles that does not fall immediately to the
C                          bottom
C                          caco3 particles
C      *rrc*       REAL    remaining fraction of newly formed biogenic p
C      *po4r*      REAL    ratio (moles p)/(moles c) (redfield ratio p:c
C      *po4*       REAL    initial phosphate concentration related to
C                          total co2 by redfield ratio (easier handling
C                          of po4 during calculation) [moles/l]
C      *opal*      REAL    initial sio2 concentration [moles/l]
C                          (not used in this model version)
C      *alka0*     REAL    initial value for alkalinity [eqv/l]
C      *oxyg0*     REAL    initial value for dissolved o2 [moles/l]
C      *calc0*     REAL    initial value for caco3 particles in water
C                          column [moles/l]
C      *bioma0*    REAL    initial value for concentration of poc
C                          [moles]
C      *stac14*    REAL    reference co2 concentration for initiation of
C                          ocean total co2-14c
C      *f0*        REAL    factor for converting reference 14c concentra
C                          stac14 to initial ocean total co2-14c
C      *sumco*     REAL    total 14c inventory [mole]
C      *sumfl*     REAL    sum of array dlll(ie,je), converts 14c inven-
C                          tory in amount 14c [moles] per [cm**2]
C                          (dlll= horizontal spacing in zonal direction
C                                  between two grid points [cm])

C     -----------------------------------------------------------------
      DIMENSION dm0(ke),ds0(ke),dc0(ke)
      DATA dm0/11*0./
      DATA dc0/11*0./
      DATA ds0/6*0.,5*0.2/

C     -----------------------------------------------------------------
C*         1. set e-folding depth for penetration of newly formed
C             biogenic poc [cm]
C             -------- --- ------ --- ----------- -- ----- ------

       pendeo=60000.

C     -----------------------------------------------------------------
C*         2. set e-folding depth for penetration of newly formed
C             biogenic caco3 particles [cm]
C             -------- ----- -------------------- -- ----- ------

       pendec=400000.

C     -----------------------------------------------------------------
C*         3. set cristallization rate in caco3 supersaturated water
C             --- --------------- ---- -- ----- -------------- -----

      cristl=0.

C     -----------------------------------------------------------------
C*         4. set fraction of newly formed biogenic poc that falls
C             immediately to the bottom layer (ke)
C             ----------- -- --- ------ ----- ----- --- ---- -----

C     fecpef=0.
C     drif=1.-fecpef

C     -----------------------------------------------------------------
C*         5. set fraction of newly formed biogenic caco3 particles
C             that falls immediately to the bottom layer (ke)
C             ---- ----- ----------- -- --- ------ ----- ----------

      bigshl=0.2
      dric=1.-bigshl

C     -----------------------------------------------------------------
C*         6. calculate vertical distribution of newly formed
C             biogenic poc and caco3 particles in the water column
C             in the case of max. possible bottom depth
C             -- --- ---- -- ---- -------- ------ --------- ------


c old code -- changed archer 12-11-91
      flux50=1./(0.0238*real(intw(2))*1.e-2+0.212)
      restor=1.-flux50
      fecpef=bigshl*restor
      drires=restor-fecpef
      drif=1.-fecpef
      rrc=dric
      rro=drif
      tobbb=intw(2)
      tob=intw(2)
      ke1=ke-1
      DO 1633 k=2,ke1
      tun=intw(k+1)
C     dm0(k)=drif*(EXP(-(tob-tobbb)/pendeo)-EXP(-(tun-tobbb)/pendeo))
c      dm0(k)=drif*(1./(0.0238*real(intw(k))*1.e-2+0.212)
c     .              -1./(0.0238*real(intw(k+1))*1.e-2+0.212))
c     .        +drires*
c     .              (EXP(-(tob-tobbb)/pendec)-EXP(-(tun-tobbb)/pendec))
c      dc0(k)=dric*(EXP(-(tob-tobbb)/pendec)-EXP(-(tun-tobbb)/pendec))
      rrc=rrc-dc0(k)
      rro=rro-dm0(k)
      tob=tun
1633  CONTINUE
      dc0(ke)=rrc
      dm0(ke)=rro

c!!!!      

c   dm0 numbers, * delz(1)/delz(k) * prorca, = addition rate of
c     tracer, in moles/l timestep
c     formulation from john martin, DSR 87

c      e_martin = -0.6
      e_martin = -0.7
c      e_martin = -0.85
      e_calcite = 2000. * 100.
      f_bigshl = 0.3
      k = 2
      dm0(k) = 1. - ( intw(3) / 1e4 )**(e_martin)
      dc0(k) = (1.-f_bigshl)
     *       - (1.-f_bigshl) * exp( -intw(3)/(e_calcite) ) 
      DO 1643 k=3, ke
         dm0(k) = ( intw(k)/1e4)**(e_martin)
     *          - ( intw(k+1)  /1e4)**(e_martin)
         dc0(k) = (1.-f_bigshl) *
     *            ( ( exp( -intw(k)/(e_calcite) ) )
     *            - ( exp( -intw(k+1)  /(e_calcite) ) )
     *            )
 1643 CONTINUE
      poc_flux_frac = 1.d0
      do k=2,ke
         poc_flux_frac(k) = MIN(1.,(intw(k)/1e4)**(e_martin))
      enddo
      dmtot = 0.
      dctot = 0.
      DO 1644 k=2,ke
         dmtot = dmtot + dm0(k)
         dctot = dctot + dc0(k)
 1644 CONTINUE

      
C     -----------------------------------------------------------------
C*         7. set redfield ratio moles n (+ hpo4-) / moles c
C             (for change in alkalinity due to production/remine-
C             ralization of organic matter)
C             n:c=16:122, see takahashi et al. (1985), p. 6923

C             composition of planktonic material and respiration:
C             c106h263o110n16p + 138 o2 ->
C            -> 106 co2 + 16 no3- + hpo4(2-) + 122 h2o + 18 h+  ,
C             see degens et al. (1984), p. 152
C             --- ------ -- --- ------- -- --- --- --- - -- -- --
      rno3=(16.+2.)/122.
C     rno3=17.5/133.

C     -----------------------------------------------------------------
C*         8. set redfield ratio moles p / moles c
C             (see takahashi et al., 1985, p. 6923)
C             ---- --------- -- ---- ----- -- -----

      po4r=1./122.
C     po4r=1./133.

C     -----------------------------------------------------------------
C*         9. set ratio moles o2 consumed / c returned to solution
C             during remineralization
C             (see takahashi et al., 1985, p. 6923)
C             ---- --------- -- ---- ----- -- -------- -- --------

      o2ut=172./122.
C     o2ut=177./133.

C     -----------------------------------------------------------------
C*        10. set ratio c-c(organic)/c-cacao3 in biogenic particles
C             --- ----- --------------------- -- -------- ---------

      caco3r=0.25
c      caco3r=0.3

C     -----------------------------------------------------------------
C*        11. set ratio moles c / moles sio4 in biogenic particles
C             --- ----- ----- - - ----- ---- -- -------- ---------

      sio2r=0.75

C     -----------------------------------------------------------------
C*        12. set initial [po4] (related to carbon by redfield ratio
C             for easier computational handling)
C             --- ------ ------------- ----------- -- -------- -----

       po4=2.1e-6/po4r

C     -----------------------------------------------------------------
C*        13. set initial value of [sio2]
C             --- ------ ------ -- ------

      opal=1.e-4

C     -----------------------------------------------------------------
C*        14. set approximate fractionation factors of 13c, 14c
C             for evaporation (without temperature dependency)
C             --- ----------- -------- ----------- -----------

      evfr13=0.992
      evfr14=evfr13**2

C     -----------------------------------------------------------------
C*        15. set fractionation factors of 13c, 14c for carbon
C             built into organic planktonic material
C             ----- ---- ------- ---------- ----------- ------

      plafr13=0.980
      plafr14=plafr13**2

C     -----------------------------------------------------------------
C*        16. set remineralization rate for poc (fraction poc to
C             be remineralised during one time step
C             -- ------------- ------ --- ---- ---------- --- --

      remira(1)=1.
      DO 334 k=2,ke
        remira(k)=0.05
 334  CONTINUE

C     -----------------------------------------------------------------
C*        17. set inertia concentration of caco3 for
C             spontaneous dissolution [moles/l]
C             ----------- ----------- ---------- ---

C      dispo0=1.e-5
       dispo0=1.e-4

C     -----------------------------------------------------------------
C*        18. set minimum [o2] [moles/l] for bacterial decomposition
C             organic matter
C             ------- -------- --------- --- --------- -------------

      oxymin=1.e-5

C     -----------------------------------------------------------------
C*        19. set michaelis menton constant of productivity (half satu-
C             ration constant; nutrient concentration, where nutrient
C             uptake velocity is half its potential maximum value;
C             e.g. dugdale (1967), parsons and takahashi (1973))
C             ---- ------- ------- ------- --- --------- -----------

c      = 40 uM (from Bacastow and EMR 1990)
C       conc0=2.e-6
C       conc0=1.e-5
       conc0=1.e-5

C     -----------------------------------------------------------------
C*        20. calculate vertical distribution of newly formed
C             biogenic poc and caco3 particles in the water column
C             with reabiolic topography (lowest wet layer contains
C             total fraction, which has passed the upper layers)
C                (dmin3(i,j,k) - poc
C                (disc3(i,j,k) - caco3 particles
C                (dmin3(i,j,k) - sio4 particles)
C             ---------------- - ---- ------------ ----- ---------

c     zero the arrays
      DO 51 j=jl1,jle
      DO 51 i=1,ie
         dminl(i,j)=zero
         discl(i,j)=zero
         dissl(i,j)=zero
         sdfxoc(i,j)=1-dmtot
         sdfxca(i,j)=1-dctot
51    CONTINUE

c     work up from the bottom
      DO 60 k=ke,1,-1

c        first guess, the open water (general) values
         DO 601 j=jl1,jle
            DO 601 i=1,ie
               diss3(i,j,k)=ds0(k)
               dmin3(i,j,k)=dm0(k)
               disc3(i,j,k)=dc0(k)
  601    CONTINUE

c        now if no water in a given box, accumulate flux
c          in the "l" arrays and set dmin3 etc to 0.
         DO 602 j=jl1,jle
            DO 602 i=1,ie
               IF(ddz(i,j,k).LT.one) then
                  dissl(i,j)=dissl(i,j)+diss3(i,j,k)
                  discl(i,j)=discl(i,j)+disc3(i,j,k)
                  dminl(i,j)=dminl(i,j)+dmin3(i,j,k)
                  diss3(i,j,k)=zero
                  dmin3(i,j,k)=zero
                  disc3(i,j,k)=zero
               ENDIF
  602    CONTINUE

c        if there is water, and if sinking flux has
c          "accumulated" in dminl etc arrays, then
c          donate that to sedflux arrays


         DO 603 j=jl1,jle
            DO 603 i=1,ie
               IF(ddz(i,j,k).GT.one) then
                  sdfxoc(i,j)=sdfxoc(i,j)+dminl(i,j)
                  sdfxca(i,j)=sdfxca(i,j)+discl(i,j)
                  dminl(i,j)=zero
                  dissl(i,j)=zero
                  discl(i,j)=zero

c     but just put that in dmin3, etc, for now
                  dmin3(i,j,k) = dmin3(i,j,k)+sdfxoc(i,j)
                  disc3(i,j,k) = disc3(i,j,k)+sdfxca(i,j)
                  sdfxoc(i,j) = 0.
                  sdfxca(i,j) = 0.
               ENDIF
  603    CONTINUE

   60 CONTINUE

      DO 604 j=jl1,jle
         DO 604 i=1,ie
            IF(ddz(i,j,1).LT.0.5)then
               dmin3(i,j,1)=0.
               diss3(i,j,1)=0.
               disc3(i,j,1)=0.
               sdfxoc(i,j)=0.
               sdfxca(i,j)=0.
            ENDIF
604   CONTINUE

C*        20.1 test if depth integral of dmin3, disc3 diss3 = 1
      DO 122 j=jl1,jle
      DO 122 i=1,ie
         discl(i,j)=0.
         dminl(i,j)=0.
  122 CONTINUE
      DO 123 k=1,ke
         DO 123 j=jl1,jle
            DO 123 i=1,ie
               dminl(i,j)=dminl(i,j)+dmin3(i,j,k)
               discl(i,j)=discl(i,j)+disc3(i,j,k)
123   CONTINUE

      DO 1230 j=jl1,jle
         DO 1230 i=1,ie
            dminl(i,j)=dminl(i,j)+sdfxoc(i,j)
            discl(i,j)=discl(i,j)+sdfxca(i,j)
            IF((ddz(i,j,1).NE. 0) .AND. dminl(i,j).LT. 1.) THEN
c               write(6,*) i,j,dminl(i,j)
               sdfxoc(i,j) = sdfxoc(i,j) + 1. - dminl(i,j)
            ENDIF
            IF((ddz(i,j,1).NE. 0) .AND. discl(i,j).LT. 1.) THEN
c               write(6,*) i,j,discl(i,j)
               sdfxca(i,j) = sdfxca(i,j) + 1. - discl(i,j)
            ENDIF
 1230 CONTINUE

C     WRITE(6,69134)((dminl(i,j),i=1,12),j=jl1,jle)
C     WRITE(6,69134)((discl(i,j),i=1,12),j=jl1,jle)
C new in crun64a begin
      DO 2229 k=1,ke
         DO 2229 j=1,je
            DO 2229 i=1,ie
               spocri(i,j,k)=0.
 2229 CONTINUE
      DO 2230 j=jl1,jle
         DO 2230 i=1,ie
            DO 2231 k=1,ke-1
               spocri(i,j,ke)=1.
               IF(ddz(i,j,k+1).LT.0.01)then
                  spocri(i,j,ke)=0.
                  spocri(i,j,k)=1.
                  GOTO 2230
               ENDIF
 2231       CONTINUE
 2230 CONTINUE

C new in crun64a END

C     -----------------------------------------------------------------
C*        21. set initial value of total alkalinity [eqv/l]
C             --- ------- ----- -- ----- ---------- -------

C     alka0=2.45e-3
      alka0=2.45e-3*1.015

C     -----------------------------------------------------------------
C*        22. set initial [sum((12c)o2)] [mole/l]
C             --- ------- -------------- -------

       sco2=2.35e-3

C     -----------------------------------------------------------------
C*        23. set pre-industrial atmospheric [co2] (ppm)
C             --- -------------- ----------- ----- -----

      praei=270.

C     -----------------------------------------------------------------
C*        23a. initiate mean atmospheric [co2] [ppm]
C             -------- ---- ----------- ----- -----

      atqqq=praei

C     -----------------------------------------------------------------
C*        24. set initial dissolved [o2] [mole/l]
C             --- ------- --------- ---- --------

      oxyg0=2.e-4

C     -----------------------------------------------------------------
C*        25. set initial biogenic particulate [caco3] [mole/l]
C             --- ------- -------- ----------- ------- --------

      calc0=1.e-5

C     -----------------------------------------------------------------
C*        26. set initial [poc] [mole/l]
C             --- ------- ----- --------

      bioma0=1.e-12

C     -----------------------------------------------------------------
C*        27. set regional deviation from optimal productivity (dark-
C             ness, turbulence etc. ...) and pre-industrial atmospheric
C             [co2]
C             (max. value for prlat which makes sense is 1.)
C             ----- ----- --- ----- ----- ----- ----- -- --------------

C *** modif. instead
C     prlat(i,j)=4.
C glockenkurve fuer prlat nach einstrahlung(lambda) (selley)
C prlat mal 4 fuer biodvektion
      DO 1800 j=1,je
      DO 1800 i=1,ie
      atc(i,j,1)=praei
      atc(i,j,2)=praei
      atc(i,j,3)=praei
1800  CONTINUE
C***new in crun051 89/05/12 begin
      DO 1801 i=1,ie
C glockenkurve von mir nach sellers 1965 begin
C     prlat(i, 1)=   .367879
C     prlat(i, 2)=   .387756
C     prlat(i, 3)=   .408127
C     prlat(i, 4)=   .428956
C     prlat(i, 5)=   .450209
C     prlat(i, 6)=   .471842
C     prlat(i, 7)=   .493812
C     prlat(i, 8)=   .516071
C     prlat(i, 9)=   .538566
C     prlat(i,10)=   .561244
C     prlat(i,11)=   .584045
C     prlat(i,12)=   .606908
C     prlat(i,13)=   .629770
C     prlat(i,14)=   .652565
C     prlat(i,15)=   .675224
C     prlat(i,16)=   .697676
C     prlat(i,17)=   .719851
C     prlat(i,18)=   .741675
C     prlat(i,19)=   .763074
C     prlat(i,20)=   .783975
C     prlat(i,21)=   .804304
C     prlat(i,22)=   .823987
C     prlat(i,23)=   .842953
C     prlat(i,24)=   .861129
C     prlat(i,25)=   .878447
C     prlat(i,26)=   .894839
C     prlat(i,27)=   .910242
C     prlat(i,28)=   .924595
C     prlat(i,29)=   .937838
C     prlat(i,30)=   .949920
C     prlat(i,31)=   .960789
C     prlat(i,32)=   .970402
C     prlat(i,33)=   .978719
C     prlat(i,34)=   .985703
C     prlat(i,35)=   .991327
C     prlat(i,36)=   .995565
C     prlat(i,37)=   .998401
C     prlat(i,38)=   .999822
C     prlat(i,39)=   .999822
C     prlat(i,40)=   .998401
C     prlat(i,41)=   .995565
C     prlat(i,42)=   .991327
C     prlat(i,43)=   .985703
C     prlat(i,44)=   .978719
C     prlat(i,45)=   .970402
C     prlat(i,46)=   .960789
C     prlat(i,47)=   .949920
C     prlat(i,48)=   .937838
C     prlat(i,49)=   .924595
C     prlat(i,50)=   .910242
C     prlat(i,51)=   .894839
C     prlat(i,52)=   .878447
C     prlat(i,53)=   .861129
C     prlat(i,54)=   .842953
C     prlat(i,55)=   .823987
C     prlat(i,56)=   .804304
C     prlat(i,57)=   .783975
C     prlat(i,58)=   .763074
C     prlat(i,59)=   .741675
C     prlat(i,60)=   .719851
C     prlat(i,61)=   .697676
C     prlat(i,62)=   .675224
C     prlat(i,63)=   .652565
C     prlat(i,64)=   .629770
C     prlat(i,65)=   .606908
C     prlat(i,66)=   .584045
C     prlat(i,67)=   .561244
C     prlat(i,68)=   .538566
C     prlat(i,69)=   .516071
C     prlat(i,70)=   .493812
C     prlat(i,71)=   .471842
C     prlat(i,72)=   .450209
C     prlat(i,73)=   .428956
C     prlat(i,74)=   .408127
C     prlat(i,75)=   .387756
C     prlat(i,76)=   .367879
C glockenkurve von mir nach sellers 1965 END
C kurve aus bacastow and maier-reimer  begin
      prlat(i, 1)=  0.0
      prlat(i, 2)=  0.0
      prlat(i, 3)=   .3420
      prlat(i, 4)=   .3443
      prlat(i, 5)=   .3487
      prlat(i, 6)=   .3554
      prlat(i, 7)=   .3644
      prlat(i, 8)=   .3761
      prlat(i, 9)=   .3905
      prlat(i,10)=   .4082
      prlat(i,11)=   .4289
      prlat(i,12)=   .4527
      prlat(i,13)=   .4791
      prlat(i,14)=   .5078
      prlat(i,15)=   .5382
      prlat(i,16)=   .5696
      prlat(i,17)=   .6016
      prlat(i,18)=   .6336
      prlat(i,19)=   .6652
      prlat(i,20)=   .6960
      prlat(i,21)=   .7259
      prlat(i,22)=   .7549
      prlat(i,23)=   .7826
      prlat(i,24)=   .8091
      prlat(i,25)=   .8341
      prlat(i,26)=   .8575
      prlat(i,27)=   .8792
      prlat(i,28)=   .8992
      prlat(i,29)=   .9174
      prlat(i,30)=   .9339
      prlat(i,31)=   .9487
      prlat(i,32)=   .9616
      prlat(i,33)=   .9726
      prlat(i,34)=   .9818
      prlat(i,35)=   .9891
      prlat(i,36)=   .9946
      prlat(i,37)=   .9982
      prlat(i,38)=  1.0
      prlat(i,39)=  1.0
      prlat(i,40)=   .9982
      prlat(i,41)=   .9946
      prlat(i,42)=   .9891
      prlat(i,43)=   .9818
      prlat(i,44)=   .9726
      prlat(i,45)=   .9616
      prlat(i,46)=   .9487
      prlat(i,47)=   .9339
      prlat(i,48)=   .9174
      prlat(i,49)=   .8992
      prlat(i,50)=   .8792
      prlat(i,51)=   .8575
      prlat(i,52)=   .8341
      prlat(i,53)=   .8091
      prlat(i,54)=   .7826
      prlat(i,55)=   .7549
      prlat(i,56)=   .7259
      prlat(i,57)=   .6960
      prlat(i,58)=   .6652
      prlat(i,59)=   .6336
      prlat(i,60)=   .6061
      prlat(i,61)=   .5696
      prlat(i,62)=   .5382
      prlat(i,63)=   .5078
      prlat(i,64)=   .4791
      prlat(i,65)=   .4527
      prlat(i,66)=   .4289
      prlat(i,67)=   .4082
      prlat(i,68)=   .3905
      prlat(i,69)=   .3761
      prlat(i,70)=   .3644
      prlat(i,71)=   .3554
      prlat(i,72)=   .3487
      prlat(i,73)=   .3443
      prlat(i,74)=   .3420
      prlat(i,75)=  0.0
      prlat(i,76)=  0.0
C kurve aus bacastow and maier-reimer  END
 1801 CONTINUE
C     DO 1802 j=1,je
C     DO 1802 i=1,ie
C       prlat(i,j)=5.*1./(1.+0.01*(real(j)-38.5)**2)
C       IF(i.EQ.1)print*,'prlat j  ',prlat(i,j),j
 1802 CONTINUE
C***new in crun051 89/05/12 END


C     -----------------------------------------------------------------
C*        28. initiate ocean arrays of total alkalinity, [o2], [po4],
C             [sum(co2)], [poc] and [caco3] (for different c-isotopes)
C             (for 14c see below also)
C             ---- --- --- ----- ---------- ---- --------- -----------
      ca = 0.d0
      DO 2000 k=1,ke
      DO 2000 j=1,je
      DO 2000 i=1,ie
      sco212(i,j,k)=sco2
      sco213(i,j,k)=sco2
      sco214(i,j,k)=sco2
      alkali(i,j,k)=alka0
      oxygen(i,j,k)=oxyg0
      phosph(i,j,k)=po4
2000  CONTINUE

      hg_surf_tot_old = 0.d0
      hg_199_surf_tot_old = 0.d0
      hg_202_surf_tot_old = 0.d0

C     -----------------------------------------------------------------
C*        29. initiate inorganic 14c
C             -------- --------- ---
      stac14=sco2
      DO 80287 k=1,ke
      f0=0.96
      IF(k.ge.4) f0=0.83
      DO 80287 j=jl1,jle
      DO 80287 i=1,ie
      sco214(i,j,k)=f0*stac14
80287 CONTINUE

C     -----------------------------------------------------------------
C*        30. total c-14 inventory (sumco)
C             ----- ---- ---------

      sumfl=0.
      sumco=0.
      DO 270 k=1,ke
      DO 270 j=jl1,jle
      DO 270 i=1,ie
      sumco=sumco+dzdl(i,j,k)*sco214(i,j,k)
c     *        +calc14(i,j,k)+
c     .  poc14(i,j,k))
270   CONTINUE
      DO 271 j=jl1,jle
      DO 271 i=1,ie
      sumco=sumco+atc(i,j,3)*dlll(i,j)*0.033
      sumfl=sumfl+dlll(i,j)
271   CONTINUE
      DO 272 j=jl1,jle
      DO 272 i=1,ie
c      sumco=sumco+ccsd14(i,j)*dlll(i,j)
c      sumco=sumco+ocsd14(i,j)*dlll(i,j)
272   CONTINUE

C     -----------------------------------------------------------------
C*        32. decay rate of c-14 in whole system per second
C             = amount that has to be produced in the atmosphere
C             per s if steady state for 14c inventory is assumed
C             --- - -- ------ ----- --- --- --------- -- -------

C     prc14=30.30303*deccon*sumco/sumfl
      prc14=deccon*sumco/(sumfl*0.033)

C     -----------------------------------------------------------------
C*        33. amount c14 that has suffered radio decay during one
C             timestep
C             = amount that has to be produced in the atmosphere
C             during one time step if steady state for 14c
C             inventory is assumed
C             --------- -- ------- -- ------ ----- --- ----------

      prc14t=dt*prc14

C     -----------------------------------------------------------------
C*        34. set initial productivities for soft tissue and
C             calcite =0
C             ----------- -------------- --- ---- ------ ---

      DO 7000 j=1,je
      DO 7000 i=1,ie
        prorca(i,j)=0.
        prcaca(i,j)=0.
 7000 CONTINUE

c      print*,' setting of biological PARAMETERs '
c      print*,' rno3=   ',rno3
c      print*,' caco3r= ',caco3r
c      print*,' cristl= ',cristl,' see spocri'
c      print*,' evfr13,evfr14 =',evfr13,evfr14
c      print*,' plafr13,plafr14=',plafr13,plafr14
c      print*, 'o2ut=',o2ut
c      print*,' po4r=',po4r
c      print*,' dispo0= ',dispo0
C***new in crun61b begin
      DO 4372 iv=1,nv
      DO 4372 k=1,ke
      DO 4372 j=1,jl1-1
      DO 4372 i=1,ie
        ca(i,j,k,iv)=0.
        cn(i,j,k,iv)=0.
 4372 CONTINUE
      DO 4373 iv=1,nv
      DO 4373 k=1,ke
      DO 4373 j=jle+1,je
      DO 4373 i=1,ie
        ca(i,j,k,iv)=0.
        cn(i,j,k,iv)=0.
 4373 CONTINUE
C***new in crun61b END

      RETURN
624   FORMAT(10f6.3)
69134 FORMAT(1x,12f9.6)
      END


      SUBROUTINE chemin

C**** *chemin* - sets chemical constants

C     e. maier-reimer      mpi hamburg      88/07/01.

C     purpose.
C     --------
C          *chemin* sets chemical constants


C**   interface.
C     ----------
C          *call* *chemin*

C     method.
C     -------
C          1) set constants for carbonate chemistry as described in
C             in broecker et al. (1982, geosecs) and edmond a. gieskes
C             (1970)
C          2) initiate [co3--] and ph-value by iteration
C             (newton-raphson method for solving nonlinear simultaneous
C              equations, see e.g. scarborough, j. (1958))


C     externals.
C     ----------
C          *rho*     - half precision function, eq. of state of
C                      seawater

C     reference.
C     ----------

C          berner, r. a. (1976)
C          the solubility of calcite and aragonite in sea water
C          at atmospheric pressure and 34.5 o/oo salinity.
C          american journal of science, vol. 276, 713-730.
C          (k'sp(aragonite)=1.45 k'sp(calcite))

C          broecker, w.s., d.w. spencer, and h. craig (1982)
C          geosecs pacific expedition. vol. 3.. hydrographic DATA
C          1973-1974, superintendant of documents, u.s. government
C          printing office, washington, d.c., 137 pp..

C          culberson, c.h., and r.m. pytkowicz (1968)
C          effect on pressure on carbonic acid, boric acid and the ph
C          in sea water.
C          limnology and oceanography, vol. 13, 403-417.

C          dickson, a.g., and j.p. riley (1979)
C          the estimation of acid dissociation constants in seawater
C          media from potentiometric titrations with strong base.
C          i. the ionic product of water - kw.
C          marine chemistry, vol. 7, 89-99.

C          edmond, j.m., and j.m.t.m. gieskes (1970)
C          on the calculation of the degree of saturation of sea water
C          with respect to calcium carbonate under in situ conditions.
C          geochim. et cosmochim. acta, 34, 1261-1291.

C          ingle, s.e. (1975)
C          solubility of calcite in the ocean.
C          marine chemistry, vol. 3, 301-319.

C          ingle, s.e., c.h. culberson, j.e. hawley, and r.m. pytkowicz
C          (1973) the solubility of calcite in seawater at atmospheric
C          pressure and 35 o/oo salinity.
C          marine chemistry, vol. 1, 295-307.

C          riley, j. p., and g. skirrow, eds. (1965)
C          chemical oceanography. vol. 1, 712 pp., academic press,
C          london a. new york.

C          scarborough, j. (1958) numerical mathematical analysis.
C          oxford university press, london, 4th ed., 576 pp..

C          weiss, r. f. (1970) the solubility of nitrogen
C          oxygen and argon in water and seawater.
C          deep-sea research, vol. 17, 721-735.

C          weiss, r. f. (1974)
C          carbon dioxide in water and seawater: the solubility of a
C          non ideal gas. marine chemistry, vol. 2, 203-215.

C          wooster, w.s., a.j. lee, and g. dietrich (1969)
C          redefinition of salinity. z. geophys., vol.35, 611-613.

C          broecker, w.s., d.w. spencer, and h. craig (1982)
C          geosecs pacific expedition. vol. 3.. hydrographic DATA
C          1973-1974, superintendant of documents, u.s. government
C          printing office, washington, d.c., 137 pp..


C*     variable           type    purpose.
C      --------           ----    --------

C      *supsat(ke)*       REAL    co3-- superstauration
C      *conveg(ie,je,ke)* REAL    check for convergence of newton-raphso
C                                 method
C      *third*            REAL    1./3. half precision
C      *tfree*            REAL    approximate value of freezing point of
C                                 seawater
C      *tboil*            REAL    sets upper limit for seawater temperat
C      *sweet*            REAL    sets lower limit for salinity
C      *brine*            REAL    sets upper limit for salinity
C      *ten*              REAL    10. half precision
C      *thousi*           REAL    0.001 half precicion
C      *smicr*            REAL    1e-6 half precision
C      *salchl*           REAL    conversion factor to calculate chlorid
C                                 concentration
C                                 s(o/oo)=1.80655*cl(o/oo)
C                                 kalle/dietrich , p. 60, or
C                                 wooster et al., 1969.
C      *temzer*           REAL    zero deg c expressed as abs. temperatu
C                                 (deg kelvin)
C      *perc*             REAL    0.01 half precision
C      *akcc1*            REAL    coefficient for empirically determined
C                                 apparent solubility product k'sp of
C                                 calcite (ingle, 1975, eq. 6)
C                                 (cf. broecker et al., 1982)
C      *akcc2*            REAL    coefficient for empirically determined
C                                 apparent solubility product k'sp of
C                                 calcite (ingle, 1975, eq. 6)
C                                 (cf. broecker et al., 1982)
C      *akcc3*            REAL    coefficient for empirically determined
C                                 apparent solubility product k'sp of
C                                 calcite (ingle, 1975, eq. 6)
C                                 (cf. broecker et al., 1982)
C      *akcc4*            REAL    coefficient for empirically determined
C                                 apparent solubility product k'sp of
C                                 calcite (ingle, 1975, eq. 6)
C                                 (cf. broecker et al., 1982)
C      *arafra*           REAL    fraction of aragonite in biogenic caco
C                                 particles (e.g. 0.3 for 30 percent)
C      *calfra*           REAL    fraction of calcite in biogenic caco3
C                                 particles (e.g. 0.3 for 30 percent)
C      *aracal*           REAL    factor to convert app. calcite solubil
C                                 product (0 dbar) to the app. solubilit
C                                 product of aragonite (berner, 1976;
C                                 cf. broecker et al., 1982)
C      *devk1*            REAL    coefficient for seawater pressure corr
C                                 of 1. dissociation constant of carboni
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devk2*            REAL    coefficient for seawater pressure corr
C                                 of 2. dissociation constant of carboni
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devkb*            REAL    coefficient for seawater pressure corr
C                                 of 1. dissociation constant of boric
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devk1t*           REAL    coefficient for seawater pressure corr
C                                 of first dissociation constant of carb
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devk2t*           REAL    coefficient for seawater pressure corr
C                                 of second dissociation constant of car
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devkbt*           REAL    coefficient for seawater pressure corr
C                                 of dissociation constant of boric
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devks*            REAL    coefficient for pressure correction of
C                                 solubility product of calcite or arago
C                                 after edmond and gieskes (1970), p. 12
C                                 (reference to culberson and pytkowicz,
C                                 as done in broecker et al., 1982, is
C                                 not correct)
C      *devkst*           REAL    coefficient for pressure correction of
C                                 solubility product of calcite or arago
C                                 after edmond and gieskes (1970), p. 12
C                                 in term with temperature
C                                 (reference to culberson and pytkowicz,
C                                 as done in broecker et al., 1982, is
C                                 not correct)
C      *rgas*             REAL    universal gas constant (boltzmann's co
C                                 times avogadro's constant =
C                                 1.3804e-16*6.023*10e+23=8.3143e+7 erg/
C                                 83.143e+6 erg/grd*mol=8.3143 j/k*mol)
C                                 multiplied with 10 (to account for
C                                 change from bar to dbar)
C                                 (cf. edmond and gieskes, 1970. p. 1285
C                                 broecker et al., 1982, p. 79)
C      *bor1*             REAL    total boron content in g/kg at cl=19 o
C                                 (s=35)
C                                 (cf. riley and skirrow, vol. 1, p. 648
C      *bor2*             REAL    inverse of atomic weight of boron for
C                                 converting specific total borate in
C                                 concentrations
C      *oxyco*            REAL    invers of normal molal volume of an
C                                 ideal gas [cm**-3]
C      *c00*              REAL    volumetric solubility constant a1 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c01*              REAL    volumetric solubility constant a2 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c02*              REAL    volumetric solubility constant a3 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c03*              REAL    volumetric solubility constant b1 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c04*              REAL    volumetric solubility constant b2 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c05*              REAL    volumetric solubility constant b3 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c10*              REAL    coeff. for 1. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c11*              REAL    coeff. for f1. h2co3 dissoc. const. af
C                                 edmond and gieskes (1970)
C      *c12*              REAL    coeff. for 1. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c13*              REAL    coeff. for 1. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c20*              REAL    coeff. for 2. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c21*              REAL    coeff. for 2. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c22*              REAL    coeff. for 2. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c23*              REAL    coeff. for 2. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cb0*              REAL    coeff. for 1. h3bo3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cb1*              REAL    coeff. for 1. h3bo3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cb2*              REAL    coeff. for 1. h3bo3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cb3*              REAL    coeff. for 1. h3bo3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cw0*              REAL    coeff. for kw (dickson and riley, 1979
C      *cw1*              REAL    coeff. for kw (dickson and riley, 1979
C      *cw2*              REAL    coeff. for kw (dickson and riley, 1979
C                                 (corrected according to b. bacastow,
C                                 pers. commun., 1988)
C      *ox0*              REAL    volumetric solubility constant a1 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox1*              REAL    volumetric solubility constant a2 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox2*              REAL    volumetric solubility constant a3 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox3*              REAL    volumetric solubility constant a4 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox4*              REAL    volumetric solubility constant b1 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox5*              REAL    volumetric solubility constant b2 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox6*              REAL    volumetric solubility constant b3 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *t*                REAL    dummy variable, absolute seawater temp
C      *q*                REAL    dummy variable, absolute seawater temp
C                                 divided by 100.
C      *s*                REAL    dummy variable, salinity
C      *cl*               REAL    chlorinity (cl(o/oo)=s(o/oo)/1.80655)
C                                 after wooster et al., 1969
C                                 (c.f. kalle/dietrich , p. 60)
C      *cek0*             REAL    ln(k0), logarithm of co2 solubility in
C                                 seawater in volumetric units (eq. 12 i
C                                 weiss, 1974)
C      *ck1*              REAL    pk1-value (k1= 1. h2co3 dissoc. const.
C                                 after edmond and gieskes (1970)
C      *ck2*              REAL    pk2-value (k2= 2. h2co3 dissoc. const.
C                                 after edmond and gieskes (1970)
C      *ckb*              REAL    pkb-value (kb= 1. h3bo3 dissoc. const.
C                                 after edmond and gieskes (1970)
C      *ckw*              REAL    pkw-value (kw=h2o dissoc. const.) afte
C                                 dickson and riley (1979)
C      *oxy*              REAL    ln(c*), logarithm of o2 solubility in
C                                 seawater in volumetric units (eq. 4 in
C                                 weiss, 1970)
C      *ak1*              REAL    k1, 1. h2co3 dissoc. constant
C                                 (edmond and gieskes, 1970)
C      *ak2*              REAL    k2, 2. h2co3 dissoc. constant
C                                 (edmond and gieskes, 1970)
C      *akb*              REAL    kb, 1. h3bo3 dissoc. constant
C                                 (edmond and gieskes, 1970)
C      *akw*              REAL    kw, h2o dissoc. constant (dickson u.
C                                 riley, 1979)
C      *ak0*              REAL    EXP(ln(k0))=k0 co2 solubility in seawa
C                                 in volumetric units (ml/l)(weiss, 1974
C                                 cf. eq. 12)
C      *rrr*              REAL    sigma-t in ocean model, dummy variable
C                                 (used for calculation of total borat
C                                 concentration) (sigma-t=rho(s,t,0)/100
C      *bor*              REAL    total borat concentration , dummy var.
C      *tenm7*            REAL    10.**-7 half precision
C      *p*                REAL    approximate pressure at depth of u-poi
C                                 in bar, dummy variable
C      *aksp0*            REAL    caco3 solubility product at p=0 dbar
C                                 according to ingle (1975), eq. 6; the
C                                 citation of culberson and pytkowicz, 1
C                                 in broecker et al., 1982, is presumabl
C                                 not correct)
C      *aksp(ie,je,ke)*   REAL    caco3 solubility product at in situ pr
C                                 following the procedure described in e
C                                 and gieskes (1970), p. 1285
C      *cp*               REAL    term in exponent of equations for pres
C                                 correction of dissoc. constants (carb.
C                                 bor. acid) and calcite solub. product
C                                 (cf. broecker et al., 1982, edmond and
C                                 gieskes, 1970)
C      *tc*               REAL    temperature at ocean grid points (deg 
C                                 dummy variable
C      *caralk*           REAL    carbonate alkalinity = [hco3-]+[co3--]
C                                 [eqv/l]
C      *bicarb*           REAL    [hco3-] [mole/l], dummy variable
C      *ki*               INTEGER counts iterations for newton-raphson m
C                                 for initiation of [co3--] and [h+]
C      *h*                REAL    [h+], dummy variable
C      *r*                REAL    [co3--] [mole/l], dummy variable
C      *alka*             REAL    given alkalinity [eqv/l], dummy variab
C      *c*                REAL    given [sum(12c)o2] [mole/l], dummy var
C      *a*                REAL    alkalinity [eqv/l] as function of [co3
C                                 and [h+], dummy variable
C      *dcds*             REAL    local derivative
C                                 [sum(co2)]([co3--],h+]) -> [co3--]
C      *dads*             REAL    local derivative
C                                 [alk]([co3--],h+]) -> [co3--]
C      *dcdh*             REAL    local derivative
C                                 [sum(co2)]([co3--],h+]) -> [h+]
C      *dadh*             REAL    local derivative
C                                 [alk]([co3--],h+]) -> [h+]
C      *f*                REAL    function [alk] given minus [alk] in te
C                                 of [co3--] and [h+]
C      *cc*               REAL    [sum(co2)] [mole/l] as function of
C                                 [co3--] and [h+], dummy variable
C      *gg*               REAL    function [sum(co2)] given minus [sum(c
C                                 in terms of [co3--] and [h+]
C      *deti*             REAL    determinant with local derivatives for
C                                 newton-raphson iteration

C     -----------------------------------------------------------------
      INCLUDE 'parameter.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
      INCLUDE 'equivalence.include'
      DIMENSION supsat(ke) ,conveg(ie,je,ke)
      DATA supsat/3.,3.,2.5,2.,1.5,5*1.,0.95/

C     -----------------------------------------------------------------
C*         1. set half precision constants
C             --- ---- --------- ---------

      zero=0.
      tenm7=10.**(-7.)
      smicr=1.e-6
      thousi=1./1000.
      perc=0.01
      fourth=0.25
      third=1./3.
      half=0.5
      one=1.
      two=2.
      ten=10.

C     -----------------------------------------------------------------
C*         2. set lower/upper limits for temperature and salinity
C             --- ----------- ------ --- ----------- --- --------

      tfree=-1.9
      tboil=30.
      sweet=20.
      brine=40.

C     -----------------------------------------------------------------
C*         3. set conversion factor salinity -> chlorinity
C             (after wooster et al., 1969)
C             ------ ------- -- ---- ------- -- ----------

      salchl=1./1.80655

C     -----------------------------------------------------------------
C*         4. set zero deg centigrade at kelvin scale
C             --- ---- --- ---------- -- ------ -----

       temzer=273.16

C     -----------------------------------------------------------------
C*         5. set mean total [ca++] in seawater (moles/kg)
C             (see broecker a. peng, 1982, p. 26)
C             ([ca++](moles/kg)=1.026e-2*(s/35.) after
C             culkin(1965), cf. broecker et al. 1982)
C             ------------- --- -------- -- --- -----

      calcon=1.03e-2

C     -----------------------------------------------------------------
C*         6. set coefficients for apparent solubility equilibrium
C             of calcite (ingle, 1975, eq. 6)
C             -- ------- ------- ----- --- ----------- -----------

       akcc1=-34.452
       akcc2=-39.866
       akcc3=110.21
       akcc4=-7.5752e-6

C     -----------------------------------------------------------------
C*        6a. set fraction aragonite in biogenic caco3 particles
C             --- -------- --------- -- -------- ----- ---------

       arafra=0.

C     -----------------------------------------------------------------
C*        6b. fraction calcite in biogenic caco3 particles
C             -------- ------- -- -------- ----- ---------

       calfra=1.-arafra
       sucall=arafra+calfra
c       print*,'***sucall=',sucall,' eq 1 ??'

C     -----------------------------------------------------------------
C*         7. factor to get apparent solubility product for
C             aragonit by multiplication with apparent solubility
C             product for calcit (cf. berner, 1976,
C             or broecker et al., 1982)
C             -- -------- -- ---- ----- -- ------ --- ------- -----

      aracal=arafra*1.45+calfra
c      print*,'aracal=',aracal

C     -----------------------------------------------------------------
C*         8. set coefficients for seawater pressure correction of
C             dissociation constants of carbonic and boric acid
C             (after culberson and pytkowicz, 1968, cf. broecker
C             et al., 1982)
C             ------- -------- --- ---------- ----- --- -------- -

      devk1=24.2
      devk2=16.4
      devkb=27.5
      devk1t=0.085
      devk2t=0.04
      devkbt=0.095

C     -----------------------------------------------------------------
C*         9. set coefficients for pressure correction of solubility
C             product of caco3 corresponding to aragonite/calcite
C             ratio after edmond and gieskes (1970),
C             p. 1285
C             -- ---- -- --------- ----- ------ --- ------- -------

      devkst=0.23
      devks=32.8*arafra+35.4*calfra
c      print*,'***devks=',devks,' devkst=',devkst

C     -----------------------------------------------------------------
C*        11. set universal gas constant
C             --- --------- --- --------

         rgas=83.143

C     -----------------------------------------------------------------
C*        12. set boron concentration in sea water
C*            in g/kg per o/oo cl according
C             to riley and skirrow, 1965 (p.250)
C             -- ----- --- -------- ---- ------- -

      bor1=0.00023

C     -----------------------------------------------------------------
C*        13. set inverse of atomic weight of boron [g**-1]
C             (used to convert specific total borat into concentrations)
C             ----- -- ------- -------- ----- ----- ---- ---------------

      bor2=1./10.82

C     -----------------------------------------------------------------
C*        14. set invers of normal molal volume of an ideal gas
C             [cm**3]
C             ---------- -- ------ ----- ------ -- -- ----- ---

      oxyco=1./22414.4

C     -----------------------------------------------------------------
C*        15. set volumetric solubility constants for co2 in ml/l
C             (weiss, 1974)
C             ------- ------ --------- --------- --- --- -- ----

      c00=-58.0931
      c01=90.5069
      c02=22.2940
      c03=0.027766
      c04=-0.025888
      c05=0.0050578

C     -----------------------------------------------------------------
C*        16. set coeff. for 1. dissoc. of carbonic acid
C             (edmond and gieskes, 1970)
C             ------- --- -------- ------- -------- ----

      c10=3404.71
      c11=0.032786
      c12=-14.7122
      c13=-0.19178

C     -----------------------------------------------------------------
C*        17. set coeff. for 2. dissoc. of carbonic acid
C             (edmond and gieskes, 1970)
C             ------- --- -------- ------- -------- ----

      c20=2902.39
      c21=0.02379
      c22=-6.4710
      c23=-0.4693

C     -----------------------------------------------------------------
C*        18. set coeff. for 1. dissoc. of boric acid
C             (edmond and gieskes, 1970)
C             ------- --- -------- ------- ----- ----

      cb0=2291.90
      cb1=0.01756
      cb2=-3.385
      cb3=-0.32051

C     -----------------------------------------------------------------
C*        19. set coeff. for dissoc. of water
C             (dickson and riley, 1979, eq. 7, coefficient
C             cw2 corrected from 0.9415 to 0.09415 after
C             pers. commun. to b. bacastow, 1988)
C             ----- ------- -- -- --------- ------ -------

      cw0=3441.
      cw1=2.241
      cw2=-0.09415

C     -----------------------------------------------------------------
C*        20. set volumetric solubility constants for o2 in ml/l
C             (weiss, 1970)
C             ------- ------ --------- --------- --- -- -- ----

      ox0=-173.4292
      ox1=249.6339
      ox2=143.3483
      ox3=-21.8492
      ox4=-0.033096
      ox5=0.014259
      ox6=-0.0017

C     -----------------------------------------------------------------
C*        21. chemical constants - surface layer
C             -------- --------- - ------- -----

      DO 1 j=jl1,jle
      DO 1 i=1,ie

C*        21.1 set absolute temperature
      t=tem(i,j,1)+temzer
      q=t*perc
      s=sal(i,j,1)

C*        21.2 chlorinity (wooster et al., 1969)
      cl=s*salchl

C*        21.3 ln(k0) of solubility of co2 (eq. 12, weiss, 1974)
      cek0=c00+c01/q+c02*aLOG(q)+s*(c03+c04*q+c05*q**2)

C*        21.4 pk1, pk2 of carb. acid, pkb of boric acid after edmond an
C*             gieskes (1970)
C     ck1=c10/t+c11*t+c12+c13*cl**third
C     ck2=c20/t+c21*t+c22+c23*cl**third
      ck1=-13.7201+0.031334*t+3235.76/t+1.300e-5*s*t
     .      -0.1032*SQRT(s)
      ck2=5371.9645+1.671221*t+0.22913*s+18.3802*alog10(s)
     .      -128375.28/t-2194.3055*alog10(t)-8.0944e-4*s*t
     .      -5617.11*alog10(s)/t+2.136*s/t
      ckb=cb0/t+cb1*t+cb2+cb3*cl**third

C*        21.5 pkw (h2o) (dickson and riley, 1979)
      ckw=cw0/t+cw1+cw2*SQRT(s)

C*        21.6 ln(k0) of solubility of o2 (eq. 4, weiss, 1970)
      oxy=ox0+ox1/q+ox2*aLOG(q)+ox3*q+s*(ox4+ox5*q+ox6*q**2)

C*        21.7 k1, k2 of carb. acid, kb of boric acid (edmond and gieske
      ak1=ten**(-ck1)
      ak2=ten**(-ck2)
      akb=ten**(-ckb)

C*        21.8 ionic product of water kw (h2o) (dickson and riley, 1979)
      akw3(i,j,1)=ten**(-ckw)

C*       21.9 co2 solubility in seawater (weiss, 1974, cf. eq. 12)
      ak0=EXP(cek0)*smicr

C*       21.10 density of seawater and total borate in moles/l
      rrr=rho(s,tem(i,j,1),zero) *thousi
      bor=bor1*rrr*cl*bor2

C*       21.11 set chemical chemical constants
      chemc(i,j,5)=ak0
      chemc(i,j,4)=SQRT(ak1/ak2)
      chemc(i,j,3)=SQRT(ak1*ak2)
      chemc(i,j,1)=chemc(i,j,3)/akb
      chemc(i,j,2)=akw3(i,j,1)/chemc(i,j,3)
C     print*,'***akw3 chemc2 i j k=1 ',
C    *                  akw3(i,j,1),chemc(i,j,2),i,j
      chemc(i,j,6)=bor

C*       21.12 o2 solubility in seawater (weiss, 1970, cf. eq. 4)
      chemc(i,j,7)=EXP(oxy)*oxyco
      chemv(i,j,1)=1.e-5
      chemv(i,j,2)=4.
      chemv(i,j,5)=1.e-5
      chemv(i,j,6)=4.
C     IF(i.EQ.1) WRITE(6,622) j,t,ak1,ak2,akb,akw,ak0,bor
1     CONTINUE

C     -----------------------------------------------------------------
C*        22. chemical constants - deep ocean
C             -------- --------- - ---- -----

      DO 2 k=1,ke

C*        22.1 approx. seawater pressure at u-point depth (bar)
      p=1.025e-3*intu(k)
      DO 2 j=jl1,jle
      DO 2 i=1,ie

C*        22.2 set limits for seawater temp. and salinity
C              (this is done to avoid computational crash at dry
C               points during calculation of chemical constants)
      tem(i,j,k)=amax1(tem(i,j,k),tfree)
      tem(i,j,k)=amin1(tem(i,j,k),tboil)
      sal(i,j,k)=amax1(sal(i,j,k),sweet)
      sal(i,j,k)=amin1(sal(i,j,k),brine)

C*        22.3 set [h+] (first guess)
      hi(i,j,k)=tenm7

C*        22.4 set absolute temperature
      t=tem(i,j,k)+temzer
      q=t*perc
      s=sal(i,j,k)

C*        22.5 chlorinity (wooster et al., 1969)
      cl=s*salchl

C*        22.6 ln(k0) of solubility of co2 (eq. 12, weiss, 1974)
      cek0=c00+c01/q+c02*aLOG(q)+s*(c03+c04*q+c05*q**2)

C*        22.7 pk1, pk2 of carbonic acid, pkb of boric acid after edmond
C              and gieskes (1970)
C     ck1=c10/t+c11*t+c12+c13*cl**third
C     ck2=c20/t+c21*t+c22+c23*cl**third
      ck1=-13.7201+0.031334*t+3235.76/t+1.300e-5*s*t
     .      -0.1032*SQRT(s)
      ck2=5371.9645+1.671221*t+0.22913*s+18.3802*alog10(s)
     .      -128375.28/t-2194.3055*alog10(t)-8.0944e-4*s*t
     .      -5617.11*alog10(s)/t+2.136*s/t
      ckb=cb0/t+cb1*t+cb2+cb3*cl**third

C*        22.8 ln(k0) of solubility of o2 (eq. 4, weiss, 1970)
      oxy=ox0+ox1/q+ox2*aLOG(q)+ox3*q+s*(ox4+ox5*q+ox6*q**2)

C*        22.9 k1, k2 of carbonic acid, kb of boric acid, kw (h2o) (lit.
      ak1=ten**(-ck1)
      ak2=ten**(-ck2)
      akb=ten**(-ckb)

C*        22.9a akw3, ionic product of water (dickson u. riley, 1979)
      ckw=cw0/t+cw1+cw2*SQRT(s)
      akw3(i,j,k)=ten**(-ckw)

C*       22.10 apparent solubility product k'sp of calcite in seawater
C              (s=27-43, t=2-25 deg c) at p=0 (atmosph. pressure)
C              (ingle, 1975, eq. 6)
       aksp0=1.e-7*(akcc1+akcc2*s**(third)+akcc3*alog10(s)
     .   +akcc4*t**2)

C*       22.11 formula for cp after edmond and gieskes (1970)
C              (reference to culberson and pytkoqicz (1968) as made
C              in broecker et al. (1982) is incorrect; here rgas is
C              taken tenfold to correct for the notation of p in
C              dbar instead of bar and the expression for cp is
C              multiplied by ln(10.) to allow use of exp-function
C              with basis e in the formula for akspp (cf. edmond
C              and gieskes (1970), p. 1285 and p. 1286 (the small
C              formula on p. 1286 is right and consistent with the
C              sign in partial molar volume change as shown on
C              p. 1285))
      cp=p/(rgas*t)

C*       22.12 kb of boric acid, k1,k2 of carbonic acid pressure
C              correction after culberson and pytkowicz (1968)
C              (cf. broecker et al., 1982)
      tc=tem(i,j,k)

      akb3(i,j,k)=akb*EXP(cp*(devkb-devkbt*tc))
      ak13(i,j,k)=ak1*EXP(cp*(devk1-devk1t*tc))
      ak23(i,j,k)=ak2*EXP(cp*(devk2-devk2t*tc))

C        22.13 apparent solubility product k'sp of calcite (or aragonite
C              as function of pressure follwing edmond and gieskes (1970
C              (p. 1285) and berner (1976)
      aksp(i,j,k)=aracal*aksp0*EXP(cp*(devks-devkst*tc))

C*       22.14 density of seawater and total borate concentr. [moles/l]
      rrr=rho(s,tc,p)*thousi
      bor=bor1*rrr*cl*bor2
      borat(i,j,k)=bor

C     -----------------------------------------------------------------
C*        23. initiate [h+] and [co3--]
C             -------- ---- --- -------

C*       23.1  first guesses for [co3--] and [h+]
      caralk=alkali(i,j,k)-bor/(one+tenm7/akb3(i,j,k))
      co3(i,j,k)=caralk-sco212(i,j,k)
      bicarb=two*sco212(i,j,k)-caralk
      hi(i,j,k)=ak23(i,j,k)*bicarb/co3(i,j,k)
2     CONTINUE

       DO 33 k=1,7
       DO 34 j=jl1,jle
C      WRITE(6,622) j,(chemc(i,j,k),i=1,7)
34     CONTINUE
33     CONTINUE

C*       23.2  iteration to initiate [co3--] and [h+]
C              (newton-raphson method:
C               the values of [sum(co2)] and [alk] are given,
C               desired roots of [co3--] and [h+] for that pair
C               are determined by solving numerically the system
C               of the two nonlinear equations
C        1) [alk]given      - [alk]([co3--],[h+])      = 0 (=f)
C        2) [sum(co2)]given - [sum(co2)]([co3--],[h+]) = 0 (=gg)
      DO 43 ki=1,100
      DO 43 k=1,ke
      DO 43 j=jl1,jle
      DO 43 i=1,ie

C*       23.3  set dummy variable for total borate
      bt=borat(i,j,k)

C*       23.4  set dummy variable for [h+], and [co3--]
      h=hi(i,j,k)
      r=co3(i,j,k)

C*       23.5  set dummy variable for [alk]given and
C              [sum(co2)]given
      alka=alkali(i,j,k)
      c=sco212(i,j,k)

C*       23.6  calculate [alk]([co3--], [h+])
      a=co3(i,j,k)*(two+h/ak23(i,j,k))
     .  +akw3(i,j,k)/h-h+bt/(one+h/akb3(i,j,k))

C*       23.7  actual value of function f=[alk]given-[alk]([co3--],[h+])
      f=alka-a

C*       23.8  calculate [sum(co2)]([co3--], [h+])
      cc=r*(one+h/ak23(i,j,k)+h**2/(ak13(i,j,k)*ak23(i,j,k)))

C*       23.9  actual value of function gg=[sum(co2)]given
C                                          -[sum(co2)]([co3--],[h+])
      gg=c-cc

C*       23.10 local derivative of [sum(co2)]([co3--],[h+]) with
C              respect to [co3--]
      dcds=one+h/ak23(i,j,k)+h**2/(ak13(i,j,k)*ak23(i,j,k))

C*       23.11 local derivative of [alk]([co3--],[h+]) with
C              respect to [co3--]
      dads=two+h/ak23(i,j,k)

C*       23.12 local derivative of [sum(co2)]([co3--],[h+]) with
C              respect to [h+]
      dcdh= r*(one/ak23(i,j,k)+two*h/(ak13(i,j,k)*ak23(i,j,k)))

C*       23.13 local derivative of [alk]([co3--],[h+]) with
C              respect to [h+]
      dadh= r/ak23(i,j,k)-akw3(i,j,k)/h**2-one
     .  -bt/((one+h/akb3(i,j,k))**2*akb3(i,j,k))

C*       23.14 control variable to check convergence
      conveg(i,j,k)=gg**2+f**2

C*       23.15 solve system of linear equations for corrections
C              of [co3--] and [h+] by determinants (''cramersche
C              regel'') and add corrections to [co3--] and
C              [h+] from the preceeding step
      deti=-one/(dadh*dcds-dads*dcdh)
      co3(i,j,k)=co3(i,j,k)-deti*(dadh*gg-dcdh*f)
      hi(i,j,k)=hi(i,j,k)-deti*(dcds*f-dads*gg)
43    CONTINUE
C***check begin
C     print*,'***check subr. chemin'
C     print*,'i j k  sco2given  sco2calc  alkagiven  alkacalc'
C     DO 47 k=1,ke
C     DO 47 j=30,35
C     DO 47 i=1,ie
C       hco3=co3(i,j,k)*hi(i,j,k)/ak23(i,j,k)
C       h2co3=hco3*hi(i,j,k)/ak13(i,j,k)
C       boh4=(akb3(i,j,k)*borat(i,j,k)/hi(i,j,k))/
C    *                   (one+akb3(i,j,k)/hi(i,j,k))
C       t=tem(i,j,k)+temzer
C       s=sal(i,j,k)
C       cw0=3441.
C       cw1=2.241
C       cw2=-0.09415
C       ckw=cw0/t+cw1+cw2*SQRT(s)
C       akw=ten**(-ckw)
C       oh=akw/hi(i,j,k)
C       tccont=h2co3+hco3+co3(i,j,k)
C       tacont=hco3+two*co3(i,j,k)+boh4+oh-hi(i,j,k)
C       print*,i,j,k,sco212(i,j,k),tccont,alkali(i,j,k),tacont
C  47 CONTINUE
C***check END

C*       23.16 check for resulting [h+] of iteration
      DO 46 k=2,ke
      DO 46 j=jl1,jle
      DO 46 i=1,ie
      IF(hi(i,j,k).GT.0.) GO TO 46
c      print*,' h failure in chemin'
c      print*,i,j,k
c      print*,hi(i,j,k),conveg(i,j,k)
      STOP
46    CONTINUE

      RETURN
622   FORMAT(' ',i4,7e10.3)
      END
      SUBROUTINE chemin1(delta_t)

C**** *chemin* - sets chemical constants

C     e. maier-reimer      mpi hamburg      88/07/01.

C     purpose.
C     --------
C          *chemin* sets chemical constants


C**   interface.
C     ----------
C          *call* *chemin*

C     method.
C     -------
C          1) set constants for carbonate chemistry as described in
C             in broecker et al. (1982, geosecs) and edmond a. gieskes
C             (1970)
C          2) initiate [co3--] and ph-value by iteration
C             (newton-raphson method for solving nonlinear simultaneous
C              equations, see e.g. scarborough, j. (1958))


C     externals.
C     ----------
C          *rho*     - half precision function, eq. of state of
C                      seawater

C     reference.
C     ----------

C          berner, r. a. (1976)
C          the solubility of calcite and aragonite in sea water
C          at atmospheric pressure and 34.5 o/oo salinity.
C          american journal of science, vol. 276, 713-730.
C          (k'sp(aragonite)=1.45 k'sp(calcite))

C          broecker, w.s., d.w. spencer, and h. craig (1982)
C          geosecs pacific expedition. vol. 3.. hydrographic DATA
C          1973-1974, superintendant of documents, u.s. government
C          printing office, washington, d.c., 137 pp..

C          culberson, c.h., and r.m. pytkowicz (1968)
C          effect on pressure on carbonic acid, boric acid and the ph
C          in sea water.
C          limnology and oceanography, vol. 13, 403-417.

C          dickson, a.g., and j.p. riley (1979)
C          the estimation of acid dissociation constants in seawater
C          media from potentiometric titrations with strong base.
C          i. the ionic product of water - kw.
C          marine chemistry, vol. 7, 89-99.

C          edmond, j.m., and j.m.t.m. gieskes (1970)
C          on the calculation of the degree of saturation of sea water
C          with respect to calcium carbonate under in situ conditions.
C          geochim. et cosmochim. acta, 34, 1261-1291.

C          ingle, s.e. (1975)
C          solubility of calcite in the ocean.
C          marine chemistry, vol. 3, 301-319.

C          ingle, s.e., c.h. culberson, j.e. hawley, and r.m. pytkowicz
C          (1973) the solubility of calcite in seawater at atmospheric
C          pressure and 35 o/oo salinity.
C          marine chemistry, vol. 1, 295-307.

C          riley, j. p., and g. skirrow, eds. (1965)
C          chemical oceanography. vol. 1, 712 pp., academic press,
C          london a. new york.

C          scarborough, j. (1958) numerical mathematical analysis.
C          oxford university press, london, 4th ed., 576 pp..

C          weiss, r. f. (1970) the solubility of nitrogen
C          oxygen and argon in water and seawater.
C          deep-sea research, vol. 17, 721-735.

C          weiss, r. f. (1974)
C          carbon dioxide in water and seawater: the solubility of a
C          non ideal gas. marine chemistry, vol. 2, 203-215.

C          wooster, w.s., a.j. lee, and g. dietrich (1969)
C          redefinition of salinity. z. geophys., vol.35, 611-613.

C          broecker, w.s., d.w. spencer, and h. craig (1982)
C          geosecs pacific expedition. vol. 3.. hydrographic DATA
C          1973-1974, superintendant of documents, u.s. government
C          printing office, washington, d.c., 137 pp..


C*     variable           type    purpose.
C      --------           ----    --------

C      *supsat(ke)*       REAL    co3-- superstauration
C      *conveg(ie,je,ke)* REAL    check for convergence of newton-raphso
C                                 method
C      *third*            REAL    1./3. half precision
C      *tfree*            REAL    approximate value of freezing point of
C                                 seawater
C      *tboil*            REAL    sets upper limit for seawater temperat
C      *sweet*            REAL    sets lower limit for salinity
C      *brine*            REAL    sets upper limit for salinity
C      *ten*              REAL    10. half precision
C      *thousi*           REAL    0.001 half precicion
C      *smicr*            REAL    1e-6 half precision
C      *salchl*           REAL    conversion factor to calculate chlorid
C                                 concentration
C                                 s(o/oo)=1.80655*cl(o/oo)
C                                 kalle/dietrich , p. 60, or
C                                 wooster et al., 1969.
C      *temzer*           REAL    zero deg c expressed as abs. temperatu
C                                 (deg kelvin)
C      *perc*             REAL    0.01 half precision
C      *akcc1*            REAL    coefficient for empirically determined
C                                 apparent solubility product k'sp of
C                                 calcite (ingle, 1975, eq. 6)
C                                 (cf. broecker et al., 1982)
C      *akcc2*            REAL    coefficient for empirically determined
C                                 apparent solubility product k'sp of
C                                 calcite (ingle, 1975, eq. 6)
C                                 (cf. broecker et al., 1982)
C      *akcc3*            REAL    coefficient for empirically determined
C                                 apparent solubility product k'sp of
C                                 calcite (ingle, 1975, eq. 6)
C                                 (cf. broecker et al., 1982)
C      *akcc4*            REAL    coefficient for empirically determined
C                                 apparent solubility product k'sp of
C                                 calcite (ingle, 1975, eq. 6)
C                                 (cf. broecker et al., 1982)
C      *arafra*           REAL    fraction of aragonite in biogenic caco
C                                 particles (e.g. 0.3 for 30 percent)
C      *calfra*           REAL    fraction of calcite in biogenic caco3
C                                 particles (e.g. 0.3 for 30 percent)
C      *aracal*           REAL    factor to convert app. calcite solubil
C                                 product (0 dbar) to the app. solubilit
C                                 product of aragonite (berner, 1976;
C                                 cf. broecker et al., 1982)
C      *devk1*            REAL    coefficient for seawater pressure corr
C                                 of 1. dissociation constant of carboni
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devk2*            REAL    coefficient for seawater pressure corr
C                                 of 2. dissociation constant of carboni
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devkb*            REAL    coefficient for seawater pressure corr
C                                 of 1. dissociation constant of boric
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devk1t*           REAL    coefficient for seawater pressure corr
C                                 of first dissociation constant of carb
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devk2t*           REAL    coefficient for seawater pressure corr
C                                 of second dissociation constant of car
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devkbt*           REAL    coefficient for seawater pressure corr
C                                 of dissociation constant of boric
C                                 acid after culberson and pytkowicz, 19
C                                 (cf. broecker et al., 1982)
C      *devks*            REAL    coefficient for pressure correction of
C                                 solubility product of calcite or arago
C                                 after edmond and gieskes (1970), p. 12
C                                 (reference to culberson and pytkowicz,
C                                 as done in broecker et al., 1982, is
C                                 not correct)
C      *devkst*           REAL    coefficient for pressure correction of
C                                 solubility product of calcite or arago
C                                 after edmond and gieskes (1970), p. 12
C                                 in term with temperature
C                                 (reference to culberson and pytkowicz,
C                                 as done in broecker et al., 1982, is
C                                 not correct)
C      *rgas*             REAL    universal gas constant (boltzmann's co
C                                 times avogadro's constant =
C                                 1.3804e-16*6.023*10e+23=8.3143e+7 erg/
C                                 83.143e+6 erg/grd*mol=8.3143 j/k*mol)
C                                 multiplied with 10 (to account for
C                                 change from bar to dbar)
C                                 (cf. edmond and gieskes, 1970. p. 1285
C                                 broecker et al., 1982, p. 79)
C      *bor1*             REAL    total boron content in g/kg at cl=19 o
C                                 (s=35)
C                                 (cf. riley and skirrow, vol. 1, p. 648
C      *bor2*             REAL    inverse of atomic weight of boron for
C                                 converting specific total borate in
C                                 concentrations
C      *oxyco*            REAL    invers of normal molal volume of an
C                                 ideal gas [cm**-3]
C      *c00*              REAL    volumetric solubility constant a1 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c01*              REAL    volumetric solubility constant a2 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c02*              REAL    volumetric solubility constant a3 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c03*              REAL    volumetric solubility constant b1 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c04*              REAL    volumetric solubility constant b2 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c05*              REAL    volumetric solubility constant b3 for
C                                 the solubility of co2 in ml/l from air
C                                 at one atmosphere (weiss, 1974)
C      *c10*              REAL    coeff. for 1. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c11*              REAL    coeff. for f1. h2co3 dissoc. const. af
C                                 edmond and gieskes (1970)
C      *c12*              REAL    coeff. for 1. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c13*              REAL    coeff. for 1. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c20*              REAL    coeff. for 2. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c21*              REAL    coeff. for 2. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c22*              REAL    coeff. for 2. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *c23*              REAL    coeff. for 2. h2co3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cb0*              REAL    coeff. for 1. h3bo3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cb1*              REAL    coeff. for 1. h3bo3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cb2*              REAL    coeff. for 1. h3bo3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cb3*              REAL    coeff. for 1. h3bo3 dissoc. const. aft
C                                 edmond and gieskes (1970)
C      *cw0*              REAL    coeff. for kw (dickson and riley, 1979
C      *cw1*              REAL    coeff. for kw (dickson and riley, 1979
C      *cw2*              REAL    coeff. for kw (dickson and riley, 1979
C                                 (corrected according to b. bacastow,
C                                 pers. commun., 1988)
C      *ox0*              REAL    volumetric solubility constant a1 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox1*              REAL    volumetric solubility constant a2 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox2*              REAL    volumetric solubility constant a3 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox3*              REAL    volumetric solubility constant a4 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox4*              REAL    volumetric solubility constant b1 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox5*              REAL    volumetric solubility constant b2 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *ox6*              REAL    volumetric solubility constant b3 for
C                                 the solubility of oxygen in ml/l from
C                                 moist air at one atmosphere (weiss, 19
C      *t*                REAL    dummy variable, absolute seawater temp
C      *q*                REAL    dummy variable, absolute seawater temp
C                                 divided by 100.
C      *s*                REAL    dummy variable, salinity
C      *cl*               REAL    chlorinity (cl(o/oo)=s(o/oo)/1.80655)
C                                 after wooster et al., 1969
C                                 (c.f. kalle/dietrich , p. 60)
C      *cek0*             REAL    ln(k0), logarithm of co2 solubility in
C                                 seawater in volumetric units (eq. 12 i
C                                 weiss, 1974)
C      *ck1*              REAL    pk1-value (k1= 1. h2co3 dissoc. const.
C                                 after edmond and gieskes (1970)
C      *ck2*              REAL    pk2-value (k2= 2. h2co3 dissoc. const.
C                                 after edmond and gieskes (1970)
C      *ckb*              REAL    pkb-value (kb= 1. h3bo3 dissoc. const.
C                                 after edmond and gieskes (1970)
C      *ckw*              REAL    pkw-value (kw=h2o dissoc. const.) afte
C                                 dickson and riley (1979)
C      *oxy*              REAL    ln(c*), logarithm of o2 solubility in
C                                 seawater in volumetric units (eq. 4 in
C                                 weiss, 1970)
C      *ak1*              REAL    k1, 1. h2co3 dissoc. constant
C                                 (edmond and gieskes, 1970)
C      *ak2*              REAL    k2, 2. h2co3 dissoc. constant
C                                 (edmond and gieskes, 1970)
C      *akb*              REAL    kb, 1. h3bo3 dissoc. constant
C                                 (edmond and gieskes, 1970)
C      *akw*              REAL    kw, h2o dissoc. constant (dickson u.
C                                 riley, 1979)
C      *ak0*              REAL    EXP(ln(k0))=k0 co2 solubility in seawa
C                                 in volumetric units (ml/l)(weiss, 1974
C                                 cf. eq. 12)
C      *rrr*              REAL    sigma-t in ocean model, dummy variable
C                                 (used for calculation of total borat
C                                 concentration) (sigma-t=rho(s,t,0)/100
C      *bor*              REAL    total borat concentration , dummy var.
C      *tenm7*            REAL    10.**-7 half precision
C      *p*                REAL    approximate pressure at depth of u-poi
C                                 in bar, dummy variable
C      *aksp0*            REAL    caco3 solubility product at p=0 dbar
C                                 according to ingle (1975), eq. 6; the
C                                 citation of culberson and pytkowicz, 1
C                                 in broecker et al., 1982, is presumabl
C                                 not correct)
C      *aksp(ie,je,ke)*   REAL    caco3 solubility product at in situ pr
C                                 following the procedure described in e
C                                 and gieskes (1970), p. 1285
C      *cp*               REAL    term in exponent of equations for pres
C                                 correction of dissoc. constants (carb.
C                                 bor. acid) and calcite solub. product
C                                 (cf. broecker et al., 1982, edmond and
C                                 gieskes, 1970)
C      *tc*               REAL    temperature at ocean grid points (deg 
C                                 dummy variable
C      *caralk*           REAL    carbonate alkalinity = [hco3-]+[co3--]
C                                 [eqv/l]
C      *bicarb*           REAL    [hco3-] [mole/l], dummy variable
C      *ki*               INTEGER counts iterations for newton-raphson m
C                                 for initiation of [co3--] and [h+]
C      *h*                REAL    [h+], dummy variable
C      *r*                REAL    [co3--] [mole/l], dummy variable
C      *alka*             REAL    given alkalinity [eqv/l], dummy variab
C      *c*                REAL    given [sum(12c)o2] [mole/l], dummy var
C      *a*                REAL    alkalinity [eqv/l] as function of [co3
C                                 and [h+], dummy variable
C      *dcds*             REAL    local derivative
C                                 [sum(co2)]([co3--],h+]) -> [co3--]
C      *dads*             REAL    local derivative
C                                 [alk]([co3--],h+]) -> [co3--]
C      *dcdh*             REAL    local derivative
C                                 [sum(co2)]([co3--],h+]) -> [h+]
C      *dadh*             REAL    local derivative
C                                 [alk]([co3--],h+]) -> [h+]
C      *f*                REAL    function [alk] given minus [alk] in te
C                                 of [co3--] and [h+]
C      *cc*               REAL    [sum(co2)] [mole/l] as function of
C                                 [co3--] and [h+], dummy variable
C      *gg*               REAL    function [sum(co2)] given minus [sum(c
C                                 in terms of [co3--] and [h+]
C      *deti*             REAL    determinant with local derivatives for
C                                 newton-raphson iteration

C     -----------------------------------------------------------------
      INCLUDE 'parameter.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
c      include 'common.archer'
      INCLUDE 'equivalence.include'

      character*12 instring

      DIMENSION supsat(ke) ,conveg(ie,je,ke)
      DATA supsat/3.,3.,2.5,2.,1.5,5*1.,0.95/

C     -----------------------------------------------------------------
C*         1. set half precision constants
C             --- ---- --------- ---------

      
      zero=0.
      tenm7=10.**(-7.)
      smicr=1.e-6
      thousi=1./1000.
      perc=0.01
      fourth=0.25
      third=1./3.
      half=0.5
      one=1.
      two=2.
      ten=10.

C     -----------------------------------------------------------------
C*         2. set lower/upper limits for temperature and salinity
C             --- ----------- ------ --- ----------- --- --------

      tfree=-1.9
      tboil=30.
      sweet=20.
      brine=40.

C     -----------------------------------------------------------------
C*         3. set conversion factor salinity -> chlorinity
C             (after wooster et al., 1969)
C             ------ ------- -- ---- ------- -- ----------

      salchl=1./1.80655

C     -----------------------------------------------------------------
C*         4. set zero deg centigrade at kelvin scale
C             --- ---- --- ---------- -- ------ -----

       temzer=273.16

C     -----------------------------------------------------------------
C*         5. set mean total [ca++] in seawater (moles/kg)
C             (see broecker a. peng, 1982, p. 26)
C             ([ca++](moles/kg)=1.026e-2*(s/35.) after
C             culkin(1965), cf. broecker et al. 1982)
C             ------------- --- -------- -- --- -----

      calcon=1.03e-2

C     -----------------------------------------------------------------
C*         6. set coefficients for apparent solubility equilibrium
C             of calcite (ingle, 1975, eq. 6)
C             -- ------- ------- ----- --- ----------- -----------

       akcc1=-34.452
       akcc2=-39.866
       akcc3=110.21
       akcc4=-7.5752e-6

C     -----------------------------------------------------------------
C*        6a. set fraction aragonite in biogenic caco3 particles
C             --- -------- --------- -- -------- ----- ---------

       arafra=0.

C     -----------------------------------------------------------------
C*        6b. fraction calcite in biogenic caco3 particles
C             -------- ------- -- -------- ----- ---------

       calfra=1.-arafra
       sucall=arafra+calfra
c       print*,'***sucall=',sucall,' eq 1 ??'

C     -----------------------------------------------------------------
C*         7. factor to get apparent solubility product for
C             aragonit by multiplication with apparent solubility
C             product for calcit (cf. berner, 1976,
C             or broecker et al., 1982)
C             -- -------- -- ---- ----- -- ------ --- ------- -----

      aracal=arafra*1.45+calfra
c      print*,'aracal=',aracal

C     -----------------------------------------------------------------
C*         8. set coefficients for seawater pressure correction of
C             dissociation constants of carbonic and boric acid
C             (after culberson and pytkowicz, 1968, cf. broecker
C             et al., 1982)
C             ------- -------- --- ---------- ----- --- -------- -

      devk1=24.2
      devk2=16.4
      devkb=27.5
      devk1t=0.085
      devk2t=0.04
      devkbt=0.095

C     -----------------------------------------------------------------
C*         9. set coefficients for pressure correction of solubility
C             product of caco3 corresponding to aragonite/calcite
C             ratio after edmond and gieskes (1970),
C             p. 1285
C             -- ---- -- --------- ----- ------ --- ------- -------

      devkst=0.23
      devks=32.8*arafra+35.4*calfra
c      print*,'***devks=',devks,' devkst=',devkst

C     -----------------------------------------------------------------
C*        11. set universal gas constant
C             --- --------- --- --------

         rgas=83.143

C     -----------------------------------------------------------------
C*        12. set boron concentration in sea water
C*            in g/kg per o/oo cl according
C             to riley and skirrow, 1965 (p.250)
C             -- ----- --- -------- ---- ------- -

      bor1=0.00023

C     -----------------------------------------------------------------
C*        13. set inverse of atomic weight of boron [g**-1]
C             (used to convert specific total borat into concentrations)
C             ----- -- ------- -------- ----- ----- ---- ---------------

      bor2=1./10.82

C     -----------------------------------------------------------------
C*        14. set invers of normal molal volume of an ideal gas
C             [cm**3]
C             ---------- -- ------ ----- ------ -- -- ----- ---

      oxyco=1./22414.4

C     -----------------------------------------------------------------
C*        15. set volumetric solubility constants for co2 in ml/l
C             (weiss, 1974)
C             ------- ------ --------- --------- --- --- -- ----

      c00=-58.0931
      c01=90.5069
      c02=22.2940
      c03=0.027766
      c04=-0.025888
      c05=0.0050578

C     -----------------------------------------------------------------
C*        16. set coeff. for 1. dissoc. of carbonic acid
C             (edmond and gieskes, 1970)
C             ------- --- -------- ------- -------- ----

      c10=3404.71
      c11=0.032786
      c12=-14.7122
      c13=-0.19178

C     -----------------------------------------------------------------
C*        17. set coeff. for 2. dissoc. of carbonic acid
C             (edmond and gieskes, 1970)
C             ------- --- -------- ------- -------- ----

      c20=2902.39
      c21=0.02379
      c22=-6.4710
      c23=-0.4693

C     -----------------------------------------------------------------
C*        18. set coeff. for 1. dissoc. of boric acid
C             (edmond and gieskes, 1970)
C             ------- --- -------- ------- ----- ----

      cb0=2291.90
      cb1=0.01756
      cb2=-3.385
      cb3=-0.32051

C     -----------------------------------------------------------------
C*        19. set coeff. for dissoc. of water
C             (dickson and riley, 1979, eq. 7, coefficient
C             cw2 corrected from 0.9415 to 0.09415 after
C             pers. commun. to b. bacastow, 1988)
C             ----- ------- -- -- --------- ------ -------

      cw0=3441.
      cw1=2.241
      cw2=-0.09415

C     -----------------------------------------------------------------
C*        20. set volumetric solubility constants for o2 in ml/l
C             (weiss, 1970)
C             ------- ------ --------- --------- --- -- -- ----

      ox0=-173.4292
      ox1=249.6339
      ox2=143.3483
      ox3=-21.8492
      ox4=-0.033096
      ox5=0.014259
      ox6=-0.0017

C     -----------------------------------------------------------------
C*        21. chemical constants - surface layer
C             -------- --------- - ------- -----

      DO 1 j=jl1,jle
      DO 1 i=1,ie

C*        21.1 set absolute temperature
      t=tem(i,j,1)+temzer

#ifdef AdjTemp
      t = t + delta_t
#endif

      q=t*perc
      s=sal(i,j,1)

C*        21.2 chlorinity (wooster et al., 1969)
      cl=s*salchl

C*        21.3 ln(k0) of solubility of co2 (eq. 12, weiss, 1974)
      cek0=c00+c01/q+c02*aLOG(q)+s*(c03+c04*q+c05*q**2)

C*        21.4 pk1, pk2 of carb. acid, pkb of boric acid after edmond an
C*             gieskes (1970)
      ck1=c10/t+c11*t+c12+c13*cl**third
      ck2=c20/t+c21*t+c22+c23*cl**third
      ckb=cb0/t+cb1*t+cb2+cb3*cl**third

C*        21.5 pkw (h2o) (dickson and riley, 1979)
      ckw=cw0/t+cw1+cw2*SQRT(s)

C*        21.6 ln(k0) of solubility of o2 (eq. 4, weiss, 1970)
      oxy=ox0+ox1/q+ox2*aLOG(q)+ox3*q+s*(ox4+ox5*q+ox6*q**2)

C*        21.7 k1, k2 of carb. acid, kb of boric acid (edmond and gieske
      ak1=ten**(-ck1)
      ak2=ten**(-ck2)
      akb=ten**(-ckb)

C*        21.8 ionic product of water kw (h2o) (dickson and riley, 1979)
      akw3(i,j,1)=ten**(-ckw)

C*       21.9 co2 solubility in seawater (weiss, 1974, cf. eq. 12)
      ak0=EXP(cek0)*smicr

C*       21.10 density of seawater and total borate in moles/l
      rrr=rho(s,tem(i,j,1),zero) *thousi
      bor=bor1*rrr*cl*bor2

C*       21.11 set chemical chemical constants
      chemc(i,j,5)=ak0
      chemc(i,j,4)=SQRT(ak1/ak2)
      chemc(i,j,3)=SQRT(ak1*ak2)
      chemc(i,j,1)=chemc(i,j,3)/akb
      chemc(i,j,2)=akw3(i,j,1)/chemc(i,j,3)
C     print*,'***akw3 chemc2 i j k=1 ',
C    *                  akw3(i,j,1),chemc(i,j,2),i,j
      chemc(i,j,6)=bor

C*       21.12 o2 solubility in seawater (weiss, 1970, cf. eq. 4)
      chemc(i,j,7)=EXP(oxy)*oxyco
      chemv(i,j,1)=1.e-5
      chemv(i,j,2)=4.
      chemv(i,j,5)=1.e-5
      chemv(i,j,6)=4.
C     IF(i.EQ.1) WRITE(6,622) j,t,ak1,ak2,akb,akw,ak0,bor
1     CONTINUE

C     -----------------------------------------------------------------
C*        22. chemical constants - deep ocean
C             -------- --------- - ---- -----

      DO 2 k=1,ke

C*        22.1 approx. seawater pressure at u-point depth (bar)
      p=1.025e-3*intu(k)
      DO 2 j=jl1,jle
      DO 2 i=1,ie

C*        22.2 set limits for seawater temp. and salinity
C              (this is done to avoid computational crash at dry
C               points during calculation of chemical constants)
      tem(i,j,k)=amax1(tem(i,j,k),tfree)
      tem(i,j,k)=amin1(tem(i,j,k),tboil)
      sal(i,j,k)=amax1(sal(i,j,k),sweet)
      sal(i,j,k)=amin1(sal(i,j,k),brine)

C*        22.3 set [h+] (first guess)
      hi(i,j,k)=tenm7

C*        22.4 set absolute temperature
      t=tem(i,j,k)+temzer
      q=t*perc
      s=sal(i,j,k)

C*        22.5 chlorinity (wooster et al., 1969)
      cl=s*salchl

C*        22.6 ln(k0) of solubility of co2 (eq. 12, weiss, 1974)
      cek0=c00+c01/q+c02*aLOG(q)+s*(c03+c04*q+c05*q**2)

C*        22.7 pk1, pk2 of carbonic acid, pkb of boric acid after edmond
C              and gieskes (1970)
      ck1=c10/t+c11*t+c12+c13*cl**third
      ck2=c20/t+c21*t+c22+c23*cl**third
      ckb=cb0/t+cb1*t+cb2+cb3*cl**third

C*        22.8 ln(k0) of solubility of o2 (eq. 4, weiss, 1970)
      oxy=ox0+ox1/q+ox2*aLOG(q)+ox3*q+s*(ox4+ox5*q+ox6*q**2)

C*        22.9 k1, k2 of carbonic acid, kb of boric acid, kw (h2o) (lit.
      ak1=ten**(-ck1)
      ak2=ten**(-ck2)
      akb=ten**(-ckb)

C*        22.9a akw3, ionic product of water (dickson u. riley, 1979)
      ckw=cw0/t+cw1+cw2*SQRT(s)
      akw3(i,j,k)=ten**(-ckw)

C*       22.10 apparent solubility product k'sp of calcite in seawater
C              (s=27-43, t=2-25 deg c) at p=0 (atmosph. pressure)
C              (ingle, 1975, eq. 6)
       aksp0=1.e-7*(akcc1+akcc2*s**(third)+akcc3*alog10(s)
     .   +akcc4*t**2)

C*       22.11 formula for cp after edmond and gieskes (1970)
C              (reference to culberson and pytkoqicz (1968) as made
C              in broecker et al. (1982) is incorrect; here rgas is
C              taken tenfold to correct for the notation of p in
C              dbar instead of bar and the expression for cp is
C              multiplied by ln(10.) to allow use of exp-function
C              with basis e in the formula for akspp (cf. edmond
C              and gieskes (1970), p. 1285 and p. 1286 (the small
C              formula on p. 1286 is right and consistent with the
C              sign in partial molar volume change as shown on
C              p. 1285))
      cp=p/(rgas*t)

C*       22.12 kb of boric acid, k1,k2 of carbonic acid pressure
C              correction after culberson and pytkowicz (1968)
C              (cf. broecker et al., 1982)
      tc=tem(i,j,k)

#ifdef AdjTemp
      tc = tc + delta_t
#endif

      akb3(i,j,k)=akb*EXP(cp*(devkb-devkbt*tc))
      ak13(i,j,k)=ak1*EXP(cp*(devk1-devk1t*tc))
      ak23(i,j,k)=ak2*EXP(cp*(devk2-devk2t*tc))

C        22.13 apparent solubility product k'sp of calcite (or aragonite
C              as function of pressure follwing edmond and gieskes (1970
C              (p. 1285) and berner (1976)
      aksp(i,j,k)=aracal*aksp0*EXP(cp*(devks-devkst*tc))

C*       22.14 density of seawater and total borate concentr. [moles/l]
      rrr=rho(s,tc,p)*thousi
      bor=bor1*rrr*cl*bor2
      borat(i,j,k)=bor
      caralk=alkali(i,j,k)-bor/(one+tenm7/akb3(i,j,k))
      co3(i,j,k)=caralk-sco212(i,j,k)
      bicarb=two*sco212(i,j,k)-caralk
      hi(i,j,k)=ak23(i,j,k)*bicarb/co3(i,j,k)
2     CONTINUE


      RETURN
622   FORMAT(' ',i4,7e10.3)
      END
      SUBROUTINE inibil

C**** *inibil* - initiates inventories

C     e. maier-reimer      mpi hamburg      88/07/01.

C     purpose.
C     --------
C          *inibil* initiates balances by calculating initial inventorie

C**   interface.
C     ----------
C          *call* *inibil*

C     method.
C     -------
C          -.

C     externals.
C     ----------
C          none.

C     reference.
C     ----------
C          -.

C*     variable      type    purpose.
C      --------      ----    --------

C      *suto(nv)*    REAL    total inventory of PARAMETER iv
C      *ccsdsu*      REAL    total c inventory of caco3 sediment pool
C      *cc13su*      REAL    total c inventory of caco3 sediment pool (1
C      *cc14su*      REAL    total c inventory of caco3 sediment pool (1
C      *ocsdsu*      REAL    total c inventory of org. c sediment pool
C      *os13su*      REAL    total c inventory of org. c sediment pool (
C      *os14su*      REAL    total c inventory of org. c sediment pool (
C      *sumco2*      REAL    initial sum((12c)o2) inventory (whole syste
C      *atcc12*      REAL    atmospheric 12c inventory [mole/cm**2] fact
C      *atcc13*      REAL    atmospheric 13c inventory [mole/cm**2] fact
C      *atcc14*      REAL    atmospheric 14c inventory [mole/cm**2] fact
C      *sunc13*      REAL    initial 13c inventory (whole system)
C      *sunc14*      REAL    initial 14c inventory (whole system)
C                            variable

C     -----------------------------------------------------------------
      INCLUDE 'parameter.include'
      INCLUDE 'common.horvel'
      INCLUDE 'common.wathic'
      INCLUDE 'common.chemis'
      INCLUDE 'common.biocon'
      INCLUDE 'common.topogr'
      INCLUDE 'common.production'
      INCLUDE 'common.thermo'
      INCLUDE 'common.ctrac'
      INCLUDE 'common.divers'
      INCLUDE 'common.caco3c'
      INCLUDE 'equivalence.include'
      DIMENSION suto(nv)
      DIMENSION swit(nv,ke)
      DO 1 iv=1,nv
      DO 1 k=1,ke
        swit(iv,k)=0.
    1 CONTINUE
      swit(3,1)=1.

C     -----------------------------------------------------------------
C*         1. set half precision constants
C             --- ---- --------- ---------

      zero=0.
      two=2.

C     -----------------------------------------------------------------
C*         2. calculate initial inventories
C             --------- ------- -----------

C*         2.1 initial inventories for each single tracer
      DO 13 iv=1,nv
      suto(iv)=0.
      DO 131 k=1,ke
      DO 131 j=jl1,jle
      DO 131 i=1,ie
      suto(iv)=suto(iv)+ca(i,j,k,iv)*dzdl(i,j,k)
     .       +prorca(i,j)*swit(iv,k)*dzdl(i,j,k)
131   CONTINUE
13    CONTINUE

C*         2.2 initiate 12c, 13c, 14c inventories of caco3 sediment
C              pool, organic carbon sediment pool and atmosphere
      ccsdsu=0.
      cc14su=0.
      cc13su=0.
      ocsdsu=0.
      os14su=0.
      os13su=0.
      atcc12=0.
      atcc13=0.
      atcc14=0.
      DO 14 j=jl1,jle
      DO 14 i=1,ie
c      ccsdsu=ccsdsu+ccsd12(i,j)*dlll(i,j)
c      cc14su=cc14su+ccsd14(i,j)*dlll(i,j)
c      cc13su=cc13su+ccsd13(i,j)*dlll(i,j)
c      ocsdsu=ocsdsu+ocsd12(i,j)*dlll(i,j)
c      os14su=os14su+ocsd14(i,j)*dlll(i,j)
c      os13su=os13su+ocsd13(i,j)*dlll(i,j)
      atcc12=atcc12+atc12(i,j)*dlll(i,j)
c      atcc13=atcc13+atc13(i,j)*dlll(i,j)
c      atcc14=atcc14+atc14(i,j)*dlll(i,j)
14    CONTINUE

c      WRITE(6,647) suto,ccsdsu,ocsdsu
c      print*,' atmospant ',atcc12
c                             ,atcc13,atcc14

C*         2.3 total initial 12c, 13c, 14c inventories
      sumco2=suto(1)+suto(5)+suto(6)+ccsdsu +ocsdsu
c      sunc14=suto(8)+suto(10) +suto(12)+cc14su +os14su
c      sunc13=suto(7)+suto( 9) +suto(11)+cc13su+os13su

C   factor 0.000033 ppm -> moles/cm**2
C   factor 0.033 ppm -> (moles/cm**2)/liter  ? right ?

      sumco2=sumco2+0.033*atcc12
c      sunc14=sunc14+0.033*atcc14
c      sunc13=sunc13+0.033*atcc13
      c12inv=sumco2
c      c13inv=sunc13
c      c14inv=sunc14

C*         2.4 initial total [po4] inventory
      phoinv=suto(3)+suto(5) +ocsdsu

C*         2.5 initial inventory of total [alk]
      alkinv=suto(2)-suto(5)*rno3+two*suto(6)-ocsdsu*rno3+two*ccsdsu

c      print *, ' kohle ',sumco2,sunc13,sunc14 ,phoinv,alkinv
      RETURN
634   FORMAT(10f7.4)
644   FORMAT(' ',7e14.7)
647   FORMAT(1x,3hbil,7e18.11)
      END


      function rho(s,t,p)

C**** *rho* - calculates density of seawater (unesco, ies80)

C     emr            mpi hamburg      87/09/30.

C     purpose.
C     --------
C          *rho* calculates density of seawater depending on
C     salinity, temperature and pressure (unesco, ies 80)

C**   interface.
C     ----------
C          *rho(s,t,p)*

C               *s*     - salinity (pss78) (real, input)
C               *t*     - temp. (seawater) in deg c (real, input)
C               *p*     - pressure in seawater (atmospheric press. norma
C                         lized to 0) (in bars) (real, input)
C               *rho(s,t,p)* - density of seawater in kg/m**3

C     method.
C     -------
C          see reference.

C     externals.
C     ----------
C          none.

C     reference.
C     ----------

C          unesco (1981)
C          tenth report of the joint panel on oceanographic tables
C          and standards. unesco technical papers in marine science,
C          no. 36, paris, 25 pp.

C*     variable    type    purpose.
C      --------    ----    --------

C      *b0*        REAL    coeff. for rho at p=0 (one standard atmospher
C      *b1*        REAL    coeff. for rho at p=0 (one standard atmospher
C      *b2*        REAL    coeff. for rho at p=0 (one standard atmospher
C      *b3*        REAL    coeff. for rho at p=0 (one standard atmospher
C      *b4*        REAL    coeff. for rho at p=0 (one standard atmospher
C      *c0*        REAL    coeff. for rho at p=0 (one standard atmospher
C      *c1*        REAL    coeff. for rho at p=0 (one standard atmospher
C      *c2*        REAL    coeff. for rho at p=0 (one standard atmospher
C      *d0*        REAL    coeff. for rho at p=0 (one standard atmospher
C      *a0*        REAL    coeff. for rho of smow (iupac, 1976)
C      *a1*        REAL    coeff. for rho of smow (iupac, 1976)
C      *a2*        REAL    coeff. for rho of smow (iupac, 1976)
C      *a3*        REAL    coeff. for rho of smow (iupac, 1976)
C      *a4*        REAL    coeff. for rho of smow (iupac, 1976)
C      *a5*        REAL    coeff. for rho of smow (iupac, 1976)
C      *f0*        REAL    coeff. for secant bulk modulus of seawater
C      *f1*        REAL    coeff. for secant bulk modulus of seawater
C      *f2*        REAL    coeff. for secant bulk modulus of seawater
C      *f3*        REAL    coeff. for secant bulk modulus of seawater
C      *g0*        REAL    coeff. for secant bulk modulus of seawater
C      *g1*        REAL    coeff. for secant bulk modulus of seawater
C      *g2*        REAL    coeff. for secant bulk modulus of seawater
C      *ai0*       REAL    coeff. for secant bulk modulus of seawater
C      *ai1*       REAL    coeff. for secant bulk modulus of seawater
C      *ai2*       REAL    coeff. for secant bulk modulus of seawater
C      *aj0*       REAL    coeff. for secant bulk modulus of seawater
C      *am0*       REAL    coeff. for secant bulk modulus of seawater
C      *am1*       REAL    coeff. for secant bulk modulus of seawater
C      *am2*       REAL    coeff. for secant bulk modulus of seawater
C      *e0*        REAL    coeff. for secant bulk modulus of pure water
C      *e1*        REAL    coeff. for secant bulk modulus of pure water
C      *e2*        REAL    coeff. for secant bulk modulus of pure water
C      *e3*        REAL    coeff. for secant bulk modulus of pure water
C      *e4*        REAL    coeff. for secant bulk modulus of pure water
C      *h0*        REAL    coeff. for secant bulk modulus of pure water
C      *h1*        REAL    coeff. for secant bulk modulus of pure water
C      *h2*        REAL    coeff. for secant bulk modulus of pure water
C      *h3*        REAL    coeff. for secant bulk modulus of pure water
C      *ak0*       REAL    coeff. for secant bulk modulus of pure water
C      *ak1*       REAL    coeff. for secant bulk modulus of pure water
C      *ak1*       REAL    coeff. for secant bulk modulus of pure water
C      *s3h*       REAL    salinity**(3/2), dummy variable
C      *rhow*      REAL    density of the reference pure water (smow),
C                          (iupac, 1976)
C      *akw*       REAL    kw, secant bulk modulus pure water term
C      *aw*        REAL    aw, secant bulk modulus pure water term
C      *bw*        REAL    bw, secant bulk modulus pure water term
C      *a*         REAL    a, secant bulk modulus seawater term
C      *b*         REAL    b, secant bulk modulus seawater term
C      *akst0*     REAL    k(s,t,0), secant bulk modulus of seawater (p=
C      *akstp*     REAL    k(s,t,p), secant bulk modulus of seawater
C      *rhst0*     REAL    density of seawater at p=0 (kg/m**3)
C      *rho*       REAL    density of seawater (kg/m**3)

C     -----------------------------------------------------------------


C     -----------------------------------------------------------------
C*         1. set constants after unesco (1981)
C             --- --------- ----- ------ ------

      DATA b0,b1,b2,b3,b4/8.24493e-1,-4.0899e-3,7.6438e-5,
     .  -8.2467e-7,5.3875e-9/
      DATA c0,c1,c2/-5.72466e-3,1.0227e-4,-1.6546e-6/
      DATA d0/4.8314e-4/
      DATA a0,a1,a2,a3,a4,a5/999.842594,6.793952e-2,
     .  -9.095290e-3,1.001685e-4,-1.120083e-6,6.536332e-9/
      DATA f0,f1,f2,f3/54.6746,-0.603459,
     .  1.09987e-2,-6.1670e-5/
      DATA g0,g1,g2/7.944e-2,1.6483e-2,-5.3009e-4/
      DATA ai0,ai1,ai2/2.2838e-3,-1.0981e-5,-1.6078e-6/
      DATA aj0/1.91075e-4/
      DATA am0,am1,am2/-9.9348e-7,2.0816e-8,9.1697e-10/
      DATA e0,e1,e2,e3,e4/19652.21,148.4206,-2.327105,
     .  1.360477e-2,-5.155288e-5/
      DATA h0,h1,h2,h3/3.239908,1.43713e-3,
     .  1.16092e-4,-5.77905e-7/
      DATA ak0,ak1,ak2/8.50935e-5,-6.12293e-6,5.2787e-8/
      s3h=SQRT(s**3)

C     -----------------------------------------------------------------
C*         1. density of the reference pure water (smow) (iupac, 1976)
C             (eq. 10)
C             ---------- --- --------- ---- ----- ------ -------------

      rhow=a0+t*(a1+t*(a2+t*(a3+t*(a4+t*a5))))

C     -----------------------------------------------------------------
C*         2. pure water term of secant bulk modulus (eq. 15)
C             ---- ----- ---- -- ------ ---- ------- --------

      akw=e0+t*(e1+t*(e2+t*(e3+t*e4)))

C     -----------------------------------------------------------------
C*         3. pure water term of secant bulk modulus (eq. 16)
C             ---- ----- ---- -- ------ ---- ------- --------

      aw=h0+t*(h1+t*(h2+t*h3))

C     -----------------------------------------------------------------
C*         4. pure water term of secant bulk modulus (eq. 17)
C             ---- ----- ---- -- ------ ---- ------- --------

      bw=ak0+t*(ak1+t*ak2)

C     -----------------------------------------------------------------
C*         5. seawater term of secant bulk modulus (eq. 13)
C             -------- ---- -- ------ ---- ------- --------

      b=bw+s*(am0+t*(am1+t*am2))

C     -----------------------------------------------------------------
C*         6. seawater term of secant bulk modulus (eq. 14)
C             -------- ---- -- ------ ---- ------- --------

      a=aw+s*(ai0+t*(ai1+ai2*t))+aj0*s3h

C     -----------------------------------------------------------------
C*         7. secant bulk modulus at p=0 (eq. 12)
C             ------ ---- ------- -- --- --------

      akst0=akw+s*(f0+t*(f1+t*(f2+t*f3)))+s3h*(g0+t*(g1+g2*t))

C     -----------------------------------------------------------------
C*         8. secant bulk modulus (eq. 11)
C             ------ ---- ------- --------

      akstp=akst0+p*(a+b*p)

C     -----------------------------------------------------------------
C*         9. density of seawater at p=0 (eq. 9)
C             ------- -- -------- -- --- -------

      rhst0=rhow+s*(b0+t*(b1+t*(b2+t*(b3+t*b4))))+d0*s**2
     .  +s3h*(c0+t*(c1+c2*t))

C     -----------------------------------------------------------------
C*        10. density of seawater (eq. 7)
C             ------- -- -------- -------

      rho=rhst0/(1.-p/akstp)
      RETURN
      END
